@@ -3,7 +3,7 @@
     Smb4K.
                              -------------------
     begin                : Do Apr 2 2009
-    copyright            : (C) 2009-2019 by Alexander Reinholdt
+    copyright            : (C) 2009-2020 by Alexander Reinholdt
     email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
@@ -103,6 +103,42 @@ class Q_DECL_EXPORT Smb4KBasicNetworkItem
      */
     QUrl url() const;
     
+    /**
+     * Set @p discovered to TRUE if this network item was discovered using
+     * the DNS-SD service.
+     * 
+     * @param discovered    Set this to TRUE if the network item was discovered 
+     *                      using the DNS-SD service
+     */
+    void setDnsDiscovered(bool discovered);
+    
+    /**
+     * Return TRUE if the network item was discovered using the DNS-SD
+     * service and FALSE otherwise.
+     * 
+     * @return TRUE if discovered by DNS-SD.
+     */
+    bool dnsDiscovered() const;
+    
+    /**
+     * Set the comment for this network item.
+     * 
+     * @param comment       The comment
+     */
+    void setComment(const QString &comment);
+    
+    /**
+     * Return the comment for this network item.
+     * 
+     * @returns the comment
+     */
+    QString comment() const;
+    
+    /**
+     * Returms true, if the URL carries user information
+     */
+    bool hasUserInfo() const;
+    
   protected:
     /**
      * Expose a pointer to the private URL variable.
@@ -110,10 +146,15 @@ class Q_DECL_EXPORT Smb4KBasicNetworkItem
     QUrl *pUrl;
     
     /**
-     * Export a pointer to the private icon variable.
+     * Expose a pointer to the private icon variable.
      */
     QIcon *pIcon;
     
+    /**
+     * Expose a pointer to the private comment variable.
+     */
+    QString *pComment;
+    
   private:
     const QScopedPointer<Smb4KBasicNetworkItemPrivate> d;
 };
