@@ -2,7 +2,7 @@
     This class handles the bookmarks.
                              -------------------
     begin                : Fr Jan 9 2004
-    copyright            : (C) 2004-2019 by Alexander Reinholdt
+    copyright            : (C) 2004-2021 by Alexander Reinholdt
     email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
@@ -23,10 +23,6 @@
  *   MA 02110-1335, USA                                                    *
  ***************************************************************************/
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 // application specific includes
 #include "smb4kbookmarkhandler.h"
 #include "smb4kbookmarkhandler_p.h"
@@ -115,6 +111,43 @@ void Smb4KBookmarkHandler::addBookmark(const SharePtr &share)
 }
 
 
+void Smb4KBookmarkHandler::addBookmark(const BookmarkPtr &bookmark)
+{
+  if (bookmark)
+  {
+    //
+    // Create a list that will be passed to addBookmarks()
+    // 
+    QList<BookmarkPtr> bookmarks;
+    
+    //
+    // Check if the share has already been bookmarked and skip it if it
+    // already exists
+    //
+    BookmarkPtr knownBookmark = findBookmarkByUrl(bookmark->url());
+    
+    if (knownBookmark)
+    {
+      Smb4KNotification::bookmarkExists(knownBookmark.data());
+      return;
+    }
+    
+    //
+    // Copy the bookmark, add the correct profile (may be empty) and
+    // add it to the list.
+    // 
+    BookmarkPtr newBookmark = BookmarkPtr(bookmark);
+    newBookmark->setProfile(Smb4KProfileManager::self()->activeProfile());
+    bookmarks << newBookmark;
+    
+    //
+    // Add the bookmark
+    // 
+    addBookmarks(bookmarks, false);
+  }
+}
+
+
 void Smb4KBookmarkHandler::addBookmarks(const QList<SharePtr> &list)
 {
   //
@@ -163,7 +196,7 @@ void Smb4KBookmarkHandler::addBookmarks(const QList<SharePtr> &list)
   //
   if (!newBookmarks.isEmpty())
   {
-    QPointer<Smb4KBookmarkDialog> dlg = new Smb4KBookmarkDialog(newBookmarks, groupsList(), QApplication::activeWindow());
+    QPointer<Smb4KBookmarkDialog> dlg = new Smb4KBookmarkDialog(newBookmarks, categoryList(), QApplication::activeWindow());
     
     if (dlg->exec() == QDialog::Accepted)
     {
@@ -231,6 +264,7 @@ void Smb4KBookmarkHandler::addBookmarks(const QList<BookmarkPtr> &list, bool rep
       
     if (!existingBookmark)
     {
+      qDebug() << "Adding the bookmark to the internal list";
       d->bookmarks << bookmark;
     }
     else
@@ -258,7 +292,7 @@ void Smb4KBookmarkHandler::removeBookmark(const BookmarkPtr &bookmark)
           QString::compare(d->bookmarks.at(i)->url().toString(QUrl::RemoveUserInfo|QUrl::RemovePort),
                            bookmark->url().toString(QUrl::RemoveUserInfo|QUrl::RemovePort),
                            Qt::CaseInsensitive) == 0 &&
-          QString::compare(bookmark->groupName(), d->bookmarks.at(i)->groupName(), Qt::CaseInsensitive) == 0)
+          QString::compare(bookmark->categoryName(), d->bookmarks.at(i)->categoryName(), Qt::CaseInsensitive) == 0)
       {
         d->bookmarks.takeAt(i).clear();
         break;
@@ -272,7 +306,7 @@ void Smb4KBookmarkHandler::removeBookmark(const BookmarkPtr &bookmark)
 }
 
 
-void Smb4KBookmarkHandler::removeGroup(const QString& name)
+void Smb4KBookmarkHandler::removeCategory(const QString& name)
 {
   QMutableListIterator<BookmarkPtr> it(d->bookmarks);
   
@@ -281,7 +315,7 @@ void Smb4KBookmarkHandler::removeGroup(const QString& name)
     const BookmarkPtr &b = it.next();
     
     if ((!Smb4KSettings::useProfiles() || Smb4KSettings::activeProfile() == b->profile()) ||
-        QString::compare(b->groupName(), name, Qt::CaseInsensitive) == 0)
+        QString::compare(b->categoryName(), name, Qt::CaseInsensitive) == 0)
     {
       it.remove();
     }
@@ -305,7 +339,7 @@ void Smb4KBookmarkHandler::writeBookmarkList()
       xmlWriter.setAutoFormatting(true);
       xmlWriter.writeStartDocument();
       xmlWriter.writeStartElement("bookmarks");
-      xmlWriter.writeAttribute("version", "2.0");
+      xmlWriter.writeAttribute("version", "3.0");
 
       for (const BookmarkPtr &bookmark : d->bookmarks)
       {
@@ -317,7 +351,7 @@ void Smb4KBookmarkHandler::writeBookmarkList()
         
         xmlWriter.writeStartElement("bookmark");
         xmlWriter.writeAttribute("profile", bookmark->profile());
-        xmlWriter.writeAttribute("group", bookmark->groupName());
+        xmlWriter.writeAttribute("category", bookmark->categoryName());
 
         xmlWriter.writeTextElement("workgroup", bookmark->workgroupName());
         xmlWriter.writeTextElement("url", bookmark->url().toString(QUrl::RemoveUserInfo|QUrl::RemovePort));
@@ -370,7 +404,7 @@ void Smb4KBookmarkHandler::readBookmarkList()
       if (xmlReader.isStartElement())
       {
         if (xmlReader.name() == "bookmarks" && 
-            (xmlReader.attributes().value("version") != "1.1" && xmlReader.attributes().value("version") != "2.0"))
+            (xmlReader.attributes().value("version") != "2.0" && xmlReader.attributes().value("version") != "3.0"))
         {
           xmlReader.raiseError(i18n("The format of %1 is not supported.", xmlFile.fileName()));
           break;
@@ -383,7 +417,16 @@ void Smb4KBookmarkHandler::readBookmarkList()
             
             BookmarkPtr bookmark = BookmarkPtr(new Smb4KBookmark());
             bookmark->setProfile(profile);
-            bookmark->setGroupName(xmlReader.attributes().value("group").toString());
+            
+            if (xmlReader.attributes().hasAttribute("group"))
+            {
+              // For backward compatibility (since Smb4K 3.0.72)
+              bookmark->setCategoryName(xmlReader.attributes().value("group").toString());
+            }
+            else
+            {
+              bookmark->setCategoryName(xmlReader.attributes().value("category").toString());
+            }
               
             while (!(xmlReader.isEndElement() && xmlReader.name() == "bookmark"))
             {
@@ -395,10 +438,6 @@ void Smb4KBookmarkHandler::readBookmarkList()
                 {
                   bookmark->setWorkgroupName(xmlReader.readElementText());
                 }
-                else if (xmlReader.name() == "unc")
-                {
-                  bookmark->setUrl(xmlReader.readElementText());
-                }
                 else if (xmlReader.name() == "url")
                 {
                   bookmark->setUrl(QUrl(xmlReader.readElementText()));
@@ -459,9 +498,6 @@ void Smb4KBookmarkHandler::readBookmarkList()
 
 BookmarkPtr Smb4KBookmarkHandler::findBookmarkByUrl(const QUrl &url)
 {
-  // Update the bookmarks:
-  update();
-
   // Find the bookmark:
   BookmarkPtr bookmark;
 
@@ -469,9 +505,10 @@ BookmarkPtr Smb4KBookmarkHandler::findBookmarkByUrl(const QUrl &url)
   {
     for (const BookmarkPtr &b : bookmarksList())
     {
-      if (QString::compare(b->url().toString(QUrl::RemoveUserInfo|QUrl::RemovePort),
-                           url.toString(QUrl::RemoveUserInfo|QUrl::RemovePort),
-                           Qt::CaseInsensitive) == 0)
+      // NOTE: Since also user provided URLs can be bookmarked, we cannot use
+      // QUrl::matches() here, because it does not allow for case insensitive 
+      // comparison.
+      if (QString::compare(url.toString(QUrl::RemoveUserInfo|QUrl::RemovePort), b->url().toString(QUrl::RemoveUserInfo|QUrl::RemovePort), Qt::CaseInsensitive) == 0)
       {
         bookmark = b;
         break;
@@ -485,9 +522,6 @@ BookmarkPtr Smb4KBookmarkHandler::findBookmarkByUrl(const QUrl &url)
 
 BookmarkPtr Smb4KBookmarkHandler::findBookmarkByLabel(const QString &label)
 {
-  // Update the bookmarks:
-  update();
-
   // Find the bookmark:
   BookmarkPtr bookmark;
 
@@ -498,10 +532,6 @@ BookmarkPtr Smb4KBookmarkHandler::findBookmarkByLabel(const QString &label)
       bookmark = b;
       break;
     }
-    else
-    {
-      continue;
-    }
   }
 
   return bookmark;
@@ -518,11 +548,11 @@ QList<BookmarkPtr> Smb4KBookmarkHandler::bookmarksList() const
   {
     QList<BookmarkPtr> bookmarks;
     
-    for (const BookmarkPtr &b : d->bookmarks)
+    for (const BookmarkPtr &bookmark : d->bookmarks)
     {
-      if (b->profile() == Smb4KSettings::activeProfile())
+      if (bookmark->profile() == Smb4KSettings::activeProfile())
       {
-        bookmarks << b;
+        bookmarks << bookmark;
       }
     }
     
@@ -534,17 +564,13 @@ QList<BookmarkPtr> Smb4KBookmarkHandler::bookmarksList() const
 }
 
 
-QList<BookmarkPtr> Smb4KBookmarkHandler::bookmarksList(const QString &group) const
+QList<BookmarkPtr> Smb4KBookmarkHandler::bookmarksList(const QString &categoryName) const
 {
-  // Update bookmarks
-  update();
-
-  // Get the list of bookmarks organized in the given group
   QList<BookmarkPtr> bookmarks;
 
   for (const BookmarkPtr &bookmark : bookmarksList())
   {
-    if (QString::compare(group, bookmark->groupName(), Qt::CaseInsensitive) == 0)
+    if (categoryName == bookmark->categoryName())
     {
       bookmarks << bookmark;
     }
@@ -554,19 +580,19 @@ QList<BookmarkPtr> Smb4KBookmarkHandler::bookmarksList(const QString &group) con
 }
 
 
-QStringList Smb4KBookmarkHandler::groupsList() const
+QStringList Smb4KBookmarkHandler::categoryList() const
 {
-  QStringList groups;
+  QStringList categories;
   
   for (const BookmarkPtr &b : bookmarksList())
   {
-    if (!groups.contains(b->groupName()))
+    if (!categories.contains(b->categoryName()))
     {
-      groups << b->groupName();
+      categories << b->categoryName();
     }
   }
   
-  return groups;
+  return categories;
 }
 
 
