@@ -2,7 +2,7 @@
     This is the global namespace for Smb4K.
                              -------------------
     begin                : Sa Apr 2 2005
-    copyright            : (C) 2005-2019 by Alexander Reinholdt
+    copyright            : (C) 2005-2020 by Alexander Reinholdt
     email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
@@ -475,11 +475,18 @@ namespace Smb4KGlobal
   Q_DECL_EXPORT void openShare(SharePtr share, OpenWith openWith = FileManager);
   
   /**
-   * Get the entries of the [global] section of the smb.conf file.
+   * Get the NetBIOS name of this computer.
    * 
-   * @returns the entries of the [global] section of the smb.conf file
+   * @returns the NetBIOS name
    */
-  Q_DECL_EXPORT const QMap<QString,QString> &globalSambaOptions();
+  Q_DECL_EXPORT const QString machineNetbiosName();
+  
+  /**
+   * Get the name of the workgroup or domain this computer is in.
+   * 
+   * @returns the workgroup or domain
+   */
+  Q_DECL_EXPORT const QString machineWorkgroupName();
   
   /**
    * This function returns TRUE if the core classes should set a busy cursor when 
@@ -491,10 +498,10 @@ namespace Smb4KGlobal
   
 #if defined(Q_OS_LINUX)
   /**
-   * This list contains all whitelisted arguments for the mount.cifs binary and
+   * This list contains all allowed arguments for the mount.cifs binary and
    * is only present under the Linux operating system.
    */
-  Q_DECL_EXPORT QStringList whitelistedMountArguments();
+  Q_DECL_EXPORT QStringList allowedMountArguments();
 #endif
   
   /**
