@@ -23,10 +23,6 @@
  *   MA 02110-1335, USA                                                    *
  ***************************************************************************/
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 // application specific includes
 #include "smb4khost.h"
 #include "smb4kauthinfo.h"
@@ -45,7 +41,6 @@ class Smb4KHostPrivate
   public:
     QString workgroup;
     QHostAddress ip;
-    QString comment;
     bool isMaster;
 };
 
@@ -136,18 +131,6 @@ bool Smb4KHost::hasIpAddress() const
 }
 
 
-void Smb4KHost::setComment(const QString &comment)
-{
-  d->comment = comment;
-}
-
-
-QString Smb4KHost::comment() const
-{
-  return d->comment;
-}
-
-
 void Smb4KHost::setIsMasterBrowser(bool master)
 {
   d->isMaster = master;
