@@ -2,7 +2,7 @@
     The core class that mounts the shares.
                              -------------------
     begin                : Die Jun 10 2003
-    copyright            : (C) 2003-2020 by Alexander Reinholdt
+    copyright            : (C) 2003-2021 by Alexander Reinholdt
     email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
@@ -27,6 +27,7 @@
 #include "smb4kmounter.h"
 #include "smb4kmounter_p.h"
 #include "smb4kauthinfo.h"
+#include "smb4kworkgroup.h"
 #include "smb4kshare.h"
 #include "smb4ksettings.h"
 #include "smb4khomesshareshandler.h"
@@ -87,7 +88,7 @@ Smb4KMounter::Smb4KMounter(QObject *parent)
   d->checkTimeout = 0;
   d->newlyMounted = 0;
   d->newlyUnmounted = 0;
-  d->dialog = 0;
+  d->dialog = nullptr;
   d->firstImportDone = false;
   d->longActionRunning = false;
   d->activeProfile = Smb4KProfileManager::self()->activeProfile();
@@ -96,10 +97,6 @@ Smb4KMounter::Smb4KMounter(QObject *parent)
   // 
   // Connections
   // 
-  connect(Smb4KHardwareInterface::self(), SIGNAL(onlineStateChanged(bool)), this, SLOT(slotOnlineStateChanged(bool)));
-  connect(Smb4KHardwareInterface::self(), SIGNAL(networkShareAdded()), this, SLOT(slotTriggerImport()));
-  connect(Smb4KHardwareInterface::self(), SIGNAL(networkShareRemoved()), this, SLOT(slotTriggerImport()));
-  
   connect(Smb4KProfileManager::self(), SIGNAL(migratedProfile(QString,QString)), this, SLOT(slotProfileMigrated(QString,QString)));
   connect(Smb4KProfileManager::self(), SIGNAL(aboutToChangeProfile()), this, SLOT(slotAboutToChangeProfile()));
   connect(Smb4KProfileManager::self(), SIGNAL(activeProfileChanged(QString)), this, SLOT(slotActiveProfileChanged(QString)));
@@ -162,7 +159,7 @@ void Smb4KMounter::triggerRemounts(bool fillList)
     //
     // Process the list and honor the settings the user chose
     //
-    for (const OptionsPtr &option : options)
+    for (const OptionsPtr &option : qAsConst(options))
     {
       //
       // Skip one time remount shares, if needed
@@ -178,7 +175,7 @@ void Smb4KMounter::triggerRemounts(bool fillList)
       QList<SharePtr> mountedShares = findShareByUrl(option->url());
       bool remountShare = true;
       
-      for (const SharePtr &share : mountedShares)
+      for (const SharePtr &share : qAsConst(mountedShares))
       {
         if (!share->isForeign())
         {
@@ -194,7 +191,7 @@ void Smb4KMounter::triggerRemounts(bool fillList)
       {
         bool insertShare = true;
         
-        for (const SharePtr &share : d->remounts)
+        for (const SharePtr &share : qAsConst(d->remounts))
         {
           if (QString::compare(share->url().toString(QUrl::RemoveUserInfo|QUrl::RemovePort), option->url().toString(QUrl::RemoveUserInfo|QUrl::RemovePort)) == 0)
           {
@@ -247,13 +244,13 @@ void Smb4KMounter::import(bool checkInaccessible)
   KMountPoint::List mountPoints = KMountPoint::currentMountPoints(KMountPoint::BasicInfoNeeded|KMountPoint::NeedMountOptions);
   
   // 
-  // Now determine all mountpoints that have the SMBFS or the CIFS filesystem.
+  // Now determine all mountpoints that have the appropriate filesystem.
   // 
-  for (const QExplicitlySharedDataPointer<KMountPoint> &mountPoint : mountPoints)
+  for (const QExplicitlySharedDataPointer<KMountPoint> &mountPoint : qAsConst(mountPoints))
   {
-    if (QString::compare(mountPoint->mountType(), "cifs") == 0 || QString::compare(mountPoint->mountType(), "smbfs") == 0)
+    if (mountPoint->mountType() == "cifs" || mountPoint->mountType() == "smb3" || mountPoint->mountType() == "smbfs")
     {
-      // Create new share and set the mountpoint and the filesystem
+      // Create a new share and set the mountpoint and filesystem
       SharePtr share = SharePtr(new Smb4KShare());
       share->setUrl(mountPoint->mountedFrom());
       share->setPath(mountPoint->mountPoint());
@@ -290,8 +287,6 @@ void Smb4KMounter::import(bool checkInaccessible)
   // Check which shares were unmounted. Remove all obsolete mountpoints, emit
   // the unmounted() signal on each of the unmounted shares and remove them
   // from the global list.
-  // NOTE: The unmount() signal is emitted *BEFORE* the share is removed
-  // from the global list! You need to account for that in your application.
   //
   QList<SharePtr> unmountedShares;
   
@@ -299,9 +294,9 @@ void Smb4KMounter::import(bool checkInaccessible)
   {
     bool found = false;
     
-    for (const SharePtr &mountedShare : mountedSharesList())
+    for (const SharePtr &mountedShare : qAsConst(mountedSharesList()))
     {
-      for (const SharePtr &importedShare : d->importedShares)
+      for (const SharePtr &importedShare : qAsConst(d->importedShares))
       {
         // Check the mountpoint, since that one is unique. We will only use
         // Smb4KShare::path(), so that we do not run into trouble if a share 
@@ -333,7 +328,7 @@ void Smb4KMounter::import(bool checkInaccessible)
   {
     d->newlyUnmounted += unmountedShares.size();
     
-    for (const SharePtr &share : unmountedShares)
+    for (const SharePtr &share : qAsConst(unmountedShares))
     {
       // 
       // Remove the mountpoint if the share is not a foreign one
@@ -378,26 +373,18 @@ void Smb4KMounter::import(bool checkInaccessible)
     }
     
     //
-    // Do last things
+    // Report the number of unmounted shares to the user if it are 
+    // several ones
     // 
-    QTimer::singleShot(250, [this]() {
-      if (!isRunning())
-      {
-        //
-        // Report the number of unmounted shares to the user if it were 
-        // several ones
-        // 
-        if (d->newlyUnmounted > 1)
-        {
-          Smb4KNotification::sharesUnmounted(d->newlyUnmounted);
-        }
+    if (d->newlyUnmounted > 1)
+    {
+      Smb4KNotification::sharesUnmounted(d->newlyUnmounted);
+    }
       
-        //
-        // Reset the number of newly unmounted shares
-        // 
-        d->newlyUnmounted = 0;
-      }
-    });
+    //
+    // Reset the number of newly unmounted shares
+    // 
+    d->newlyUnmounted = 0;
 
     //
     // Tell the program the list of mounted shares changed
@@ -506,7 +493,7 @@ void Smb4KMounter::mountShare(const SharePtr &share)
     QList<SharePtr> mountedShares = findShareByUrl(url);
     bool isMounted = false;
       
-    for (const SharePtr &s : mountedShares)
+    for (const SharePtr &s : qAsConst(mountedShares))
     {
       if (!s->isForeign())
       {
@@ -694,7 +681,7 @@ void Smb4KMounter::mountShare(const SharePtr &share)
       if (errorCode == 0)
       {
         // Get the error message
-        QString errorMsg = job->data()["mh_error_message"].toString();
+        QString errorMsg = job->data().value("mh_error_message").toString();
         
         if (!errorMsg.isEmpty())
         {
@@ -728,7 +715,7 @@ void Smb4KMounter::mountShare(const SharePtr &share)
           }
 #else
           qWarning() << "Smb4KMounter::slotMountJobFinished(): Error handling not implemented!";
-          Smb4KNotification::mountingFailed(share.data(), errorMsg);
+          Smb4KNotification::mountingFailed(share, errorMsg);
 #endif
         }
       }
@@ -771,18 +758,11 @@ void Smb4KMounter::mountShares(const QList<SharePtr> &shares)
   d->longActionRunning = true;
   
   //
-  // Unmount the shares
+  // Mount the shares
   // 
   for (const SharePtr &share : shares)
   {
-    //
-    // Mount the share
-    // 
     mountShare(share);
-    
-    // Wait for 50 ms so we can act on the networkShareAdded() 
-    // signal and we do not trigger a busy error from mount
-    QTest::qWait(TIMEOUT);
   }
   
   //
@@ -912,7 +892,7 @@ void Smb4KMounter::unmountShare(const SharePtr &share, bool silent)
       if (errorCode == 0)
       {
         // Get the error message
-        QString errorMsg = job->data()["mh_error_message"].toString();
+        QString errorMsg = job->data().value("mh_error_message").toString();
         
         if (!errorMsg.isEmpty())
         {
@@ -970,10 +950,6 @@ void Smb4KMounter::unmountShares(const QList<SharePtr> &shares, bool silent)
   {
     // Unmount the share
     unmountShare(share, silent);
-    
-    // Wait for 50 ms so we can act on the networkShareRemoved() 
-    // signal and we do not trigger a busy error from umount
-    QTest::qWait(TIMEOUT);
   }
 
   //
@@ -999,8 +975,9 @@ void Smb4KMounter::openMountDialog()
   if (!d->dialog)
   {
     SharePtr share = SharePtr(new Smb4KShare());
+    BookmarkPtr bookmark = BookmarkPtr(new Smb4KBookmark());
     
-    d->dialog = new Smb4KMountDialog(share, QApplication::activeWindow());
+    d->dialog = new Smb4KMountDialog(share, bookmark, QApplication::activeWindow());
 
     if (d->dialog->exec() == QDialog::Accepted && d->dialog->validUserInput())
     {
@@ -1010,21 +987,35 @@ void Smb4KMounter::openMountDialog()
       // Bookmark the share if the user wants this.
       if (d->dialog->bookmarkShare())
       {
-        Smb4KBookmarkHandler::self()->addBookmark(share);
+        Smb4KBookmarkHandler::self()->addBookmark(bookmark);
       }
     }
 
     delete d->dialog;
-    d->dialog = 0;
+    d->dialog = nullptr;
 
     share.clear();
+    bookmark.clear();
   }
 }
 
 
 void Smb4KMounter::start()
 {
-  connect(Smb4KHardwareInterface::self(), SIGNAL(networkSessionInitialized()), this, SLOT(slotStartJobs()));
+  //
+  // Connect to the relevant signals provided by Smb4KHardwareInterface.
+  // 
+  connect(Smb4KHardwareInterface::self(), SIGNAL(onlineStateChanged(bool)), this, SLOT(slotOnlineStateChanged(bool)), Qt::UniqueConnection);
+  connect(Smb4KHardwareInterface::self(), SIGNAL(networkShareAdded()), this, SLOT(slotTriggerImport()), Qt::UniqueConnection);
+  connect(Smb4KHardwareInterface::self(), SIGNAL(networkShareRemoved()), this, SLOT(slotTriggerImport()), Qt::UniqueConnection);
+  
+  //
+  // Start with importing shares
+  // 
+  if (Smb4KHardwareInterface::self()->isOnline())
+  {
+    QTimer::singleShot(50, this, SLOT(slotStartJobs()));
+  }
 }
 
 
@@ -1140,7 +1131,6 @@ bool Smb4KMounter::fillMountActionArgs(const SharePtr &share, QVariantMap& map)
   //
   // Global and custom options
   // 
-  QMap<QString, QString> globalOptions = globalSambaOptions();
   OptionsPtr options = Smb4KCustomOptionsManager::self()->findOptions(share);
   
   //
@@ -1169,7 +1159,11 @@ bool Smb4KMounter::fillMountActionArgs(const SharePtr &share, QVariantMap& map)
   //
   // Workgroup or domain
   // 
-  if (!share->workgroupName().trimmed().isEmpty())
+  // Do not use this, if the domain is a DNS domain.
+  // 
+  WorkgroupPtr workgroup = findWorkgroup(share->workgroupName());
+  
+  if ((workgroup && !workgroup->dnsDiscovered()) && !share->workgroupName().isEmpty())
   {
     argumentsList << QString("domain=%1").arg(KShell::quoteArg(share->workgroupName()));
   }
@@ -1200,41 +1194,31 @@ bool Smb4KMounter::fillMountActionArgs(const SharePtr &share, QVariantMap& map)
   // According to the manual page, this is only needed when port 139
   // is used. So, we only pass the NetBIOS name in that case.
   // 
+  bool setNetbiosNames = false;
+  
   if (options)
   {
-    if (options->useFileSystemPort() && options->fileSystemPort() == 139)
-    {
-      // The client's NetBIOS name
-      if (!Smb4KSettings::netBIOSName().isEmpty())
-      {
-        argumentsList << QString("netbiosname=%1").arg(KShell::quoteArg(Smb4KSettings::netBIOSName()));
-      }
-      else if (!globalOptions["netbios name"].isEmpty())
-      {
-        argumentsList << QString("netbiosname=%1").arg(KShell::quoteArg(globalOptions["netbios name"]));
-      }
-      
-      // The server's NetBIOS name
-      argumentsList << QString("servernetbiosname=%1").arg(KShell::quoteArg(share->hostName()));
-    }
+    setNetbiosNames = (options->useFileSystemPort() && options->fileSystemPort() == 139);
   }
   else
   {
-    if (Smb4KMountSettings::useRemoteFileSystemPort() && Smb4KMountSettings::remoteFileSystemPort() == 139)
+    setNetbiosNames = (Smb4KMountSettings::useRemoteFileSystemPort() && Smb4KMountSettings::remoteFileSystemPort() == 139);
+  }
+  
+  if (setNetbiosNames)
+  {
+    // The client's NetBIOS name
+    if (!Smb4KSettings::netBIOSName().isEmpty())
     {
-      // The client's NetBIOS name
-      if (!Smb4KSettings::netBIOSName().isEmpty())
-      {
-        argumentsList << QString("netbiosname=%1").arg(KShell::quoteArg(Smb4KSettings::netBIOSName()));
-      }
-      else if (!globalOptions["netbios name"].isEmpty())
-      {
-        argumentsList << QString("netbiosname=%1").arg(KShell::quoteArg(globalOptions["netbios name"]));
-      }
-      
-      // The server's NetBIOS name
-      argumentsList << QString("servernetbiosname=%1").arg(KShell::quoteArg(share->hostName()));
+      argumentsList << QString("netbiosname=%1").arg(KShell::quoteArg(Smb4KSettings::netBIOSName()));
     }
+    else if (!machineNetbiosName().isEmpty())
+    {
+      argumentsList << QString("netbiosname=%1").arg(KShell::quoteArg(machineNetbiosName()));
+    }
+      
+    // The server's NetBIOS name
+    argumentsList << QString("servern=%1").arg(KShell::quoteArg(share->hostName()));
   }
   
   //
@@ -1242,62 +1226,50 @@ bool Smb4KMounter::fillMountActionArgs(const SharePtr &share, QVariantMap& map)
   // 
   // This sets the uid, gid, file_mode and dir_mode arguments, if necessary.
   // 
+  bool useCifsUnixExtensionsSupport = false;
+  QString userString, groupString, fileModeString, directoryModeString;
+  
   if (options)
   {
-    if (!options->cifsUnixExtensionsSupport())
-    {
-      // User id
-      if (options->useUser())
-      {
-        argumentsList << QString("uid=%1").arg(options->user().userId().nativeId());
-      }
-      
-      // Group id
-      if (options->useGroup())
-      {
-        argumentsList << QString("gid=%1").arg(options->group().groupId().nativeId());
-      }
-      
-      // File mode
-      if (options->useFileMode())
-      {
-        argumentsList << QString("file_mode=%1").arg(options->fileMode());
-      }
-      
-      // Directory mode
-      if (options->useDirectoryMode())
-      {
-        argumentsList << QString("dir_mode=%1").arg(options->directoryMode());
-      }
-    }
+    useCifsUnixExtensionsSupport = options->cifsUnixExtensionsSupport();
+    userString = options->useUser() ? options->user().userId().toString() : QString();
+    groupString = options->useGroup() ? options->group().groupId().toString() : QString();
+    fileModeString = options->useFileMode() ? options->fileMode() : QString();
+    directoryModeString = options->useDirectoryMode() ? options->directoryMode() : QString();
   }
   else
   {
-    if (!Smb4KMountSettings::cifsUnixExtensionsSupport())
+    useCifsUnixExtensionsSupport = Smb4KMountSettings::cifsUnixExtensionsSupport();
+    userString = Smb4KMountSettings::useUserId() ? Smb4KMountSettings::userId() : QString();
+    groupString = Smb4KMountSettings::useGroupId() ? Smb4KMountSettings::groupId() : QString();
+    fileModeString = Smb4KMountSettings::useFileMode() ? Smb4KMountSettings::fileMode() : QString();
+    directoryModeString = Smb4KMountSettings::useDirectoryMode() ? Smb4KMountSettings::directoryMode() : QString();
+  }
+  
+  if (!useCifsUnixExtensionsSupport)
+  {
+    // User id
+    if (!userString.isEmpty())
     {
-      // User id
-      if (Smb4KMountSettings::useUserId())
-      {
-        argumentsList << QString("uid=%1").arg((K_UID)Smb4KMountSettings::userId().toInt());
-      }
+      argumentsList << QString("uid=%1").arg(userString);
+    }
       
-      // Group id
-      if (Smb4KMountSettings::useGroupId())
-      {
-        argumentsList << QString("gid=%1").arg((K_GID)Smb4KMountSettings::groupId().toInt());
-      }
+    // Group id
+    if (!groupString.isEmpty())
+    {
+      argumentsList << QString("gid=%1").arg(groupString);
+    }
       
-      // File mode
-      if (Smb4KMountSettings::useFileMode())
-      {
-        argumentsList << QString("file_mode=%1").arg(Smb4KMountSettings::fileMode());
-      }
+    // File mode
+    if (!fileModeString.isEmpty())
+    {
+      argumentsList << QString("file_mode=%1").arg(fileModeString);
+    }
       
-      // Directory mode
-      if (Smb4KMountSettings::useDirectoryMode())
-      {
-        argumentsList << QString("dir_mode=%1").arg(Smb4KMountSettings::directoryMode());
-      }
+    // Directory mode
+    if (!directoryModeString.isEmpty())
+    {
+      argumentsList << QString("dir_mode=%1").arg(directoryModeString);
     }
   }
   
@@ -1332,11 +1304,6 @@ bool Smb4KMounter::fillMountActionArgs(const SharePtr &share, QVariantMap& map)
     {
       case Smb4KMountSettings::EnumClientCharset::default_charset:
       {
-        if (!globalOptions["unix charset"].isEmpty())
-        {
-          argumentsList << QString("iocharset=%1").arg(globalOptions["unix charset"].toLower());
-        }
-
         break;
       }
       default:
@@ -1368,49 +1335,37 @@ bool Smb4KMounter::fillMountActionArgs(const SharePtr &share, QVariantMap& map)
   //
   // Write access
   // 
+  bool useWriteAccess = false;
+  int writeAccess = -1;
+  
   if (options)
   {
-    if (options->useWriteAccess())
-    {
-      switch (options->writeAccess())
-      {
-        case Smb4KMountSettings::EnumWriteAccess::ReadWrite:
-        {
-          argumentsList << "rw";
-          break;
-        }
-        case Smb4KMountSettings::EnumWriteAccess::ReadOnly:
-        {
-          argumentsList << "ro";
-          break;
-        }
-        default:
-        {
-          break;
-        }
-      }
-    }
+    useWriteAccess = options->useWriteAccess();
+    writeAccess = options->writeAccess();
   }
   else
   {
-    if (Smb4KMountSettings::useWriteAccess())
+    useWriteAccess = Smb4KMountSettings::useWriteAccess();
+    writeAccess = Smb4KMountSettings::writeAccess();
+  }
+  
+  if (useWriteAccess)
+  {
+    switch (writeAccess)
     {
-      switch (Smb4KMountSettings::writeAccess())
+      case Smb4KMountSettings::EnumWriteAccess::ReadWrite:
       {
-        case Smb4KMountSettings::EnumWriteAccess::ReadWrite:
-        {
-          argumentsList << "rw";
-          break;
-        }
-        case Smb4KMountSettings::EnumWriteAccess::ReadOnly:
-        {
-          argumentsList << "ro";
-          break;
-        }
-        default:
-        {
-          break;
-        }
+        argumentsList << "rw";
+        break;
+      }
+      case Smb4KMountSettings::EnumWriteAccess::ReadOnly:
+      {
+        argumentsList << "ro";
+        break;
+      }
+      default:
+      {
+        break;
       }
     }
   }
@@ -1503,125 +1458,75 @@ bool Smb4KMounter::fillMountActionArgs(const SharePtr &share, QVariantMap& map)
   // 
   // Security mode
   // 
+  bool useSecurityMode = false;
+  int securityMode = -1;
+  
   if (options)
   {
-    if (options->useSecurityMode())
-    {
-      switch (options->securityMode())
-      {
-        case Smb4KMountSettings::EnumSecurityMode::None:
-        {
-          argumentsList << "sec=none";
-          break;
-        }
-        case Smb4KMountSettings::EnumSecurityMode::Krb5:
-        {
-          argumentsList << "sec=krb5";
-          argumentsList << QString("cruid=%1").arg(KUser(KUser::UseRealUserID).userId().nativeId());
-          break;
-        }
-        case Smb4KMountSettings::EnumSecurityMode::Krb5i:
-        {
-          argumentsList << "sec=krb5i";
-          argumentsList << QString("cruid=%1").arg(KUser(KUser::UseRealUserID).userId().nativeId());
-          break;
-        }
-        case Smb4KMountSettings::EnumSecurityMode::Ntlm:
-        {
-          argumentsList << "sec=ntlm";
-          break;
-        }
-        case Smb4KMountSettings::EnumSecurityMode::Ntlmi:
-        {
-          argumentsList << "sec=ntlmi";
-          break;
-        }
-        case Smb4KMountSettings::EnumSecurityMode::Ntlmv2:
-        {
-          argumentsList << "sec=ntlmv2";
-          break;
-        }
-        case Smb4KMountSettings::EnumSecurityMode::Ntlmv2i:
-        {
-          argumentsList << "sec=ntlmv2i";
-          break;
-        }
-        case Smb4KMountSettings::EnumSecurityMode::Ntlmssp:
-        {
-          argumentsList << "sec=ntlmssp";
-          break;
-        }
-        case Smb4KMountSettings::EnumSecurityMode::Ntlmsspi:
-        {
-          argumentsList << "sec=ntlmsspi";
-          break;
-        }
-        default:
-        {
-          // Smb4KSettings::EnumSecurityMode::Default,
-          break;
-        }
-      }
-    }
+    useSecurityMode = options->useSecurityMode();
+    securityMode = options->securityMode();
   }
   else
   {
-    if (Smb4KMountSettings::useSecurityMode())
+    useSecurityMode = Smb4KMountSettings::useSecurityMode();
+    securityMode = Smb4KMountSettings::securityMode();
+  }
+  
+  if (useSecurityMode)
+  {
+    switch (securityMode)
     {
-      switch (Smb4KMountSettings::securityMode())
+      case Smb4KMountSettings::EnumSecurityMode::None:
       {
-        case Smb4KMountSettings::EnumSecurityMode::None:
-        {
-          argumentsList << "sec=none";
-          break;
-        }
-        case Smb4KMountSettings::EnumSecurityMode::Krb5:
-        {
-          argumentsList << "sec=krb5";
-          argumentsList << QString("cruid=%1").arg(KUser(KUser::UseRealUserID).userId().nativeId());
-          break;
-        }
-        case Smb4KMountSettings::EnumSecurityMode::Krb5i:
-        {
-          argumentsList << "sec=krb5i";
-          argumentsList << QString("cruid=%1").arg(KUser(KUser::UseRealUserID).userId().nativeId());
-          break;
-        }
-        case Smb4KMountSettings::EnumSecurityMode::Ntlm:
-        {
-          argumentsList << "sec=ntlm";
-          break;
-        }
-        case Smb4KMountSettings::EnumSecurityMode::Ntlmi:
-        {
-          argumentsList << "sec=ntlmi";
-          break;
-        }
-        case Smb4KMountSettings::EnumSecurityMode::Ntlmv2:
-        {
-          argumentsList << "sec=ntlmv2";
-          break;
-        }
-        case Smb4KMountSettings::EnumSecurityMode::Ntlmv2i:
-        {
-          argumentsList << "sec=ntlmv2i";
-          break;
-        }
-        case Smb4KMountSettings::EnumSecurityMode::Ntlmssp:
-        {
-          argumentsList << "sec=ntlmssp";
-          break;
-        }
-        case Smb4KMountSettings::EnumSecurityMode::Ntlmsspi:
-        {
-          argumentsList << "sec=ntlmsspi";
-          break;
-        }
-        default:
-        {
-          // Smb4KSettings::EnumSecurityMode::Default,
-          break;
-        }
+        argumentsList << "sec=none";
+        break;
+      }
+      case Smb4KMountSettings::EnumSecurityMode::Krb5:
+      {
+        argumentsList << "sec=krb5";
+        argumentsList << QString("cruid=%1").arg(KUser(KUser::UseRealUserID).userId().nativeId());
+        break;
+      }
+      case Smb4KMountSettings::EnumSecurityMode::Krb5i:
+      {
+        argumentsList << "sec=krb5i";
+        argumentsList << QString("cruid=%1").arg(KUser(KUser::UseRealUserID).userId().nativeId());
+        break;
+      }
+      case Smb4KMountSettings::EnumSecurityMode::Ntlm:
+      {
+        argumentsList << "sec=ntlm";
+        break;
+      }
+      case Smb4KMountSettings::EnumSecurityMode::Ntlmi:
+      {
+        argumentsList << "sec=ntlmi";
+        break;
+      }
+      case Smb4KMountSettings::EnumSecurityMode::Ntlmv2:
+      {
+        argumentsList << "sec=ntlmv2";
+        break;
+      }
+      case Smb4KMountSettings::EnumSecurityMode::Ntlmv2i:
+      {
+        argumentsList << "sec=ntlmv2i";
+        break;
+      }
+      case Smb4KMountSettings::EnumSecurityMode::Ntlmssp:
+      {
+        argumentsList << "sec=ntlmssp";
+        break;
+      }
+      case Smb4KMountSettings::EnumSecurityMode::Ntlmsspi:
+      {
+        argumentsList << "sec=ntlmsspi";
+        break;
+      }
+      default:
+      {
+        // Smb4KSettings::EnumSecurityMode::Default,
+        break;
       }
     }
   }
@@ -1629,9 +1534,23 @@ bool Smb4KMounter::fillMountActionArgs(const SharePtr &share, QVariantMap& map)
   //
   // SMB protocol version
   // 
-  if (Smb4KMountSettings::useSmbProtocolVersion())
+  bool useMountProtocolVersion = false;
+  int mountProtocolVersion = -1;
+  
+  if (options)
   {
-    switch (Smb4KMountSettings::smbProtocolVersion())
+    useMountProtocolVersion = options->useMountProtocolVersion();
+    mountProtocolVersion = options->mountProtocolVersion();
+  }
+  else
+  {
+    useMountProtocolVersion = Smb4KMountSettings::useSmbProtocolVersion();
+    mountProtocolVersion = Smb4KMountSettings::smbProtocolVersion();
+  }
+  
+  if (useMountProtocolVersion)
+  {
+    switch (mountProtocolVersion)
     {
       case Smb4KMountSettings::EnumSmbProtocolVersion::OnePointZero:
       {
@@ -1653,11 +1572,26 @@ bool Smb4KMounter::fillMountActionArgs(const SharePtr &share, QVariantMap& map)
         argumentsList << "vers=3.0";
         break;
       }
+      case Smb4KMountSettings::EnumSmbProtocolVersion::ThreePointZeroPointTwo:
+      {
+        argumentsList << "vers=3.0.2";
+        break;
+      }
       case Smb4KMountSettings::EnumSmbProtocolVersion::ThreePointOnePointOne:
       {
         argumentsList << "vers=3.1.1";
         break;
       }
+      case Smb4KMountSettings::EnumSmbProtocolVersion::ThreeAndAbove:
+      {
+        argumentsList << "vers=3";
+        break;
+      }
+      case Smb4KMountSettings::EnumSmbProtocolVersion::Default:
+      {
+        argumentsList << "vers=default";
+        break;
+      }
       default:
       {
         break;
@@ -1675,7 +1609,7 @@ bool Smb4KMounter::fillMountActionArgs(const SharePtr &share, QVariantMap& map)
     //
     // This is, among others, the proper fix to the security issue reported
     // by Heiner Markert (aka CVE-2014-2581).
-    QStringList whitelist = whitelistedMountArguments();
+    QStringList allowedArgs = allowedMountArguments();
     QStringList list = Smb4KMountSettings::customCIFSOptions().split(',', QString::SkipEmptyParts);
     QMutableStringListIterator it(list);
     
@@ -1683,7 +1617,7 @@ bool Smb4KMounter::fillMountActionArgs(const SharePtr &share, QVariantMap& map)
     {
       QString arg = it.next().section("=", 0, 0);
       
-      if (!whitelist.contains(arg))
+      if (!allowedArgs.contains(arg))
       {
         it.remove();
       }
@@ -1717,9 +1651,6 @@ bool Smb4KMounter::fillMountActionArgs(const SharePtr &share, QVariantMap& map)
     map.insert("mh_url", share->homeUrl());
     map.insert("mh_homes_url", share->url());
   }  
-
-  map.insert("mh_workgroup", share->workgroupName());
-  map.insert("mh_ip", share->hostIpAddress());
   
   //
   // Location of the Kerberos ticket
@@ -1769,7 +1700,6 @@ bool Smb4KMounter::fillMountActionArgs(const SharePtr &share, QVariantMap& map)
   //
   // Global and custom options
   // 
-  QMap<QString, QString> globalOptions = globalSambaOptions();
   OptionsPtr options = Smb4KCustomOptionsManager::self()->findOptions(share);
   
   //
@@ -1778,9 +1708,13 @@ bool Smb4KMounter::fillMountActionArgs(const SharePtr &share, QVariantMap& map)
   QStringList argumentsList;
   
   //
-  // Workgroup
+  // Workgroup or domain
   // 
-  if (!share->workgroupName().isEmpty())
+  // Do not use this, if the domain is a DNS domain.
+  // 
+  WorkgroupPtr workgroup = findWorkgroup(share->workgroupName());
+  
+  if ((workgroup && !workgroup->dnsDiscovered()) && !share->workgroupName().isEmpty())
   {
     argumentsList << "-W";
     argumentsList << KShell::quoteArg(share->workgroupName());
@@ -1844,7 +1778,6 @@ bool Smb4KMounter::fillMountActionArgs(const SharePtr &share, QVariantMap& map)
     {
       case Smb4KMountSettings::EnumClientCharset::default_charset:
       {
-        clientCharset = globalOptions["unix charset"].toLower(); // maybe empty
         break;
       }
       default:
@@ -1859,7 +1792,6 @@ bool Smb4KMounter::fillMountActionArgs(const SharePtr &share, QVariantMap& map)
     {
       case Smb4KMountSettings::EnumServerCodepage::default_codepage:
       {
-        serverCharset = globalOptions["dos charset"].toLower(); // maybe empty
         break;
       }
       default:
@@ -1952,9 +1884,6 @@ bool Smb4KMounter::fillMountActionArgs(const SharePtr &share, QVariantMap& map)
     map.insert("mh_homes_url", share->url());
   }  
 
-  map.insert("mh_workgroup", share->workgroupName());
-  map.insert("mh_ip", share->hostIpAddress());
-  
   return true;
 }
 #else
@@ -2130,23 +2059,12 @@ void Smb4KMounter::check(const SharePtr &share)
 
 void Smb4KMounter::slotStartJobs()
 {
-  //
-  // Disconnect from Smb4KHardwareInterface.
-  //
-  disconnect(Smb4KHardwareInterface::self(), SIGNAL(networkSessionInitialized()), this, SLOT(slotStartJobs()));
-  
   //
   // Start the import of shares
   // 
   if (Smb4KHardwareInterface::self()->isOnline())
   {
-    //
-    // Import the mounted shares
-    //
-    if (!d->firstImportDone)
-    {
-      import(true);
-    }
+    import(true);
   }
   
   //
@@ -2193,13 +2111,13 @@ void Smb4KMounter::slotAboutToQuit()
   QStringList hostDirs = dir.entryList(QDir::Dirs|QDir::NoDotAndDotDot, QDir::NoSort);
   QStringList mountpoints;
   
-  for (const QString &hostDir : hostDirs)
+  for (const QString &hostDir : qAsConst(hostDirs))
   {
     dir.cd(hostDir);
     
     QStringList shareDirs = dir.entryList(QDir::Dirs|QDir::NoDotAndDotDot, QDir::NoSort);
     
-    for (const QString &shareDir : shareDirs)
+    for (const QString &shareDir : qAsConst(shareDirs))
     {
       dir.cd(shareDir);
       mountpoints << dir.absolutePath();
@@ -2210,13 +2128,13 @@ void Smb4KMounter::slotAboutToQuit()
   }
   
   // Remove those mountpoints where a share is actually mounted.
-  for (const QExplicitlySharedDataPointer<KMountPoint> &mountPoint : mountPoints)
+  for (const QExplicitlySharedDataPointer<KMountPoint> &mountPoint : qAsConst(mountPoints))
   {
     mountpoints.removeOne(mountPoint->mountPoint());
   }
   
   // Remove the empty mountpoints.
-  for (const QString &mp : mountpoints)
+  for (const QString &mp : qAsConst(mountpoints))
   {
     dir.cd(mp);
     dir.rmdir(dir.canonicalPath());
@@ -2234,14 +2152,9 @@ void Smb4KMounter::slotOnlineStateChanged(bool online)
   if (online)
   {
     //
-    // Trigger the remounts, but only when the first import has been done 
-    // already. Otherwise we would get errors. In this case the remounting 
-    // is done by the code in timerEvent().
-    // 
-    if (d->firstImportDone)
-    {
-      triggerRemounts(true);
-    }
+    // (Re-)start the job
+    //
+    slotStartJobs();
   }
   else
   {
@@ -2300,10 +2213,6 @@ void Smb4KMounter::slotStatResult(KJob *job)
       importedShare = d->importedShares.takeAt(i);
       break;
     }
-    else
-    {
-      continue;
-    }
   }
   
   //
@@ -2419,7 +2328,7 @@ void Smb4KMounter::slotStatResult(KJob *job)
           Smb4KNotification::shareMounted(importedShare);
         }
           
-        QTimer::singleShot(250, [this]() {
+        QTimer::singleShot(250, this, [&] () {
           if (!isRunning())
           {
             if (d->firstImportDone && d->importedShares.isEmpty() && d->newlyMounted > 1)
@@ -2510,7 +2419,16 @@ void Smb4KMounter::slotProfileMigrated(const QString& from, const QString& to)
 
 void Smb4KMounter::slotTriggerImport()
 {
-  import(true);
+  //
+  // Wait a bit so that the mount or unmount process can finish and
+  // then start importing the shares, if no jobs are running anymore
+  // 
+  QTimer::singleShot(TIMEOUT, this, [&] () {
+    if (!isRunning())
+    {
+      import(true);
+    }
+  });
 }
 
 
@@ -2518,7 +2436,7 @@ void Smb4KMounter::slotConfigChanged()
 {
   if (d->detectAllShares != Smb4KMountSettings::detectAllShares())
   {
-    slotTriggerImport();
+    import(true);
     d->detectAllShares = Smb4KMountSettings::detectAllShares();
   }
 }
