@@ -23,10 +23,6 @@
  *   MA 02110-1335, USA                                                    *
  ***************************************************************************/
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 // application specific includes
 #include "smb4kprofilemanager_p.h"
 #include "smb4ksettings.h"
@@ -93,16 +89,13 @@ void Smb4KProfileMigrationDialog::setupView()
   // The layout
   // 
   QVBoxLayout *layout = new QVBoxLayout(this);
-  layout->setSpacing(5);
   
   // 
   // The description
   // 
   QWidget *description = new QWidget(this);
-
-  QHBoxLayout *desc_layout = new QHBoxLayout(description);
-  desc_layout->setSpacing(5);
-  desc_layout->setMargin(0);
+  QHBoxLayout *descriptionLayout = new QHBoxLayout(description);
+  descriptionLayout->setContentsMargins(0, 0, 0, 0);
 
   QLabel *pixmap = new QLabel(description);
   QPixmap pix = KDE::icon("format-list-unordered").pixmap(KIconLoader::SizeHuge);
@@ -113,22 +106,21 @@ void Smb4KProfileMigrationDialog::setupView()
   label->setWordWrap(true);
   label->setAlignment(Qt::AlignBottom);
 
-  desc_layout->addWidget(pixmap, 0);
-  desc_layout->addWidget(label, Qt::AlignBottom);
+  descriptionLayout->addWidget(pixmap, 0);
+  descriptionLayout->addWidget(label, Qt::AlignBottom);
   
   //
   // The input widgets
   // 
   QWidget *editors = new QWidget(this);
-  
-  QGridLayout *editors_layout = new QGridLayout(editors);
-  editors_layout->setSpacing(5);
-  editors_layout->setMargin(0);
-  editors_layout->setColumnStretch(0, 0);
-  editors_layout->setColumnStretch(1, 1);
+  QGridLayout *editorsLayout = new QGridLayout(editors);
+  editorsLayout->setSpacing(5);
+  editorsLayout->setContentsMargins(0, 0, 0, 0);
+  editorsLayout->setColumnStretch(0, 0);
+  editorsLayout->setColumnStretch(1, 1);
   
   QLabel *from = new QLabel(i18n("Old Profile:"), editors);
-  editors_layout->addWidget(from, 0, 0, 0);
+  editorsLayout->addWidget(from, 0, 0);
   
   m_from_box = new KComboBox(editors);
   
@@ -148,10 +140,10 @@ void Smb4KProfileMigrationDialog::setupView()
     }
   }
   
-  editors_layout->addWidget(m_from_box, 0, 1, 0);
+  editorsLayout->addWidget(m_from_box, 0, 1);
   
   QLabel *to = new QLabel(i18n("New Profile:"), editors);
-  editors_layout->addWidget(to, 1, 0, 0);
+  editorsLayout->addWidget(to, 1, 0);
   
   m_to_box = new KComboBox(editors);
   
@@ -165,7 +157,7 @@ void Smb4KProfileMigrationDialog::setupView()
     m_to_box->setCurrentText(Smb4KProfileManager::self()->activeProfile());
   }
   
-  editors_layout->addWidget(m_to_box, 1, 1, 0);
+  editorsLayout->addWidget(m_to_box, 1, 1);
   
   QDialogButtonBox *buttonBox = new QDialogButtonBox(Qt::Horizontal, this);
   m_ok_button = buttonBox->addButton(QDialogButtonBox::Ok);
