@@ -23,10 +23,6 @@
  *   MA 02110-1335, USA                                                    *
  ***************************************************************************/
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 // application specific includes
 #include "smb4kshare.h"
 #include "smb4kauthinfo.h"
@@ -48,7 +44,6 @@ class Smb4KSharePrivate
 {
   public:
     QString workgroup;
-    QString comment;
     QHostAddress ip;
     QString path;
     bool inaccessible;
@@ -280,18 +275,6 @@ QString Smb4KShare::shareTypeString() const
 }
 
 
-void Smb4KShare::setComment(const QString &comment)
-{
-  d->comment = comment;
-}
-
-
-QString Smb4KShare::comment() const
-{
-  return d->comment;
-}
-
-
 void Smb4KShare::setHostIpAddress(const QString &ip)
 {
   d->ip.setAddress(ip);
@@ -604,7 +587,6 @@ QString Smb4KShare::password() const
 }
 
 
-#if KICONTHEMES_VERSION < QT_VERSION_CHECK(5,52,0)
 void Smb4KShare::setShareIcon()
 {
   if (!isPrinter())
@@ -640,43 +622,6 @@ void Smb4KShare::setShareIcon()
     *pIcon = KDE::icon("printer");
   }
 }
-#else
-void Smb4KShare::setShareIcon()
-{
-  if (!isPrinter())
-  {
-    // Overlays
-    QStringList overlays;
-    
-    if (isMounted())
-    {
-      if (isForeign())
-      {
-        overlays << "emblem-warning";
-      }
-      else
-      {
-        overlays << "";
-      }
-      
-      overlays << "emblem-mounted";
-    }
-
-    if (!isInaccessible())
-    {
-      *pIcon = KDE::icon("folder-network", overlays);
-    }
-    else
-    {
-      *pIcon = KDE::icon("folder-locked", overlays);
-    }
-  }
-  else
-  {
-    *pIcon = KDE::icon("printer");
-  }
-}
-#endif
 
 
 void Smb4KShare::update(Smb4KShare* share)
