@@ -24,10 +24,6 @@
  *   MA 02110-1335, USA                                                    *
  ***************************************************************************/
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 // application specific includes
 #include "smb4ksynchronizer_p.h"
 #include "smb4knotification.h"
@@ -692,7 +688,6 @@ Smb4KSynchronizationDialog::Smb4KSynchronizationDialog(const SharePtr &share, QW
   m_synchronize_button->setDefault(true);
 
   QGridLayout *layout = new QGridLayout(this);
-  layout->setSpacing(5);
 
   QLabel *pixmap = new QLabel(this);
   QPixmap sync_pix = KDE::icon("folder-sync").pixmap(KIconLoader::SizeHuge);
@@ -705,8 +700,7 @@ Smb4KSynchronizationDialog::Smb4KSynchronizationDialog(const SharePtr &share, QW
   description->setAlignment(Qt::AlignBottom);
 
   QUrl src_url  = QUrl(QDir::cleanPath(m_share->path()));
-  QUrl dest_url = QUrl(QDir::cleanPath(QString("%1/%2/%3").arg(Smb4KSettings::rsyncPrefix().path())
-                       .arg(m_share->hostName()).arg(m_share->shareName())));
+  QUrl dest_url = QUrl(QDir::cleanPath(QString("%1/%2/%3").arg(Smb4KSettings::rsyncPrefix().path(), m_share->hostName(), m_share->shareName())));
 
   QLabel *source_label = new QLabel(i18n("Source:"), this);
   m_source = new KUrlRequester(this);
@@ -728,13 +722,13 @@ Smb4KSynchronizationDialog::Smb4KSynchronizationDialog(const SharePtr &share, QW
   m_destination->setWhatsThis(i18n("This is the destination directory. It will be updated with the data "
     "from the source directory."));
 
-  layout->addWidget(pixmap, 0, 0, 0);
+  layout->addWidget(pixmap, 0, 0);
   layout->addWidget(description, 0, 1, Qt::AlignBottom);
-  layout->addWidget(source_label, 1, 0, 0);
-  layout->addWidget(m_source, 1, 1, 0);
-  layout->addWidget(destination_label, 2, 0, 0);
-  layout->addWidget(m_destination, 2, 1, 0);
-  layout->addWidget(buttonBox, 3, 0, 1, 2, 0);
+  layout->addWidget(source_label, 1, 0);
+  layout->addWidget(m_source, 1, 1);
+  layout->addWidget(destination_label, 2, 0);
+  layout->addWidget(m_destination, 2, 1);
+  layout->addWidget(buttonBox, 3, 0, 1, 2);
 
   // 
   // Connections
