@@ -24,10 +24,6 @@
  *   MA 02110-1335, USA                                                    *
  ***************************************************************************/
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 // application specific includes
 #include "smb4knetworkobject.h"
 #include "core/smb4kglobal.h"
@@ -202,12 +198,12 @@ QString Smb4KNetworkObject::shareName() const
 
   if (share_name.startsWith('/'))
   {
-    share_name = share_name.remove(0, 1);
+    share_name.remove(0, 1);
   }
 
   if (share_name.endsWith('/'))
   {
-    share_name = share_name.remove(share_name.size() - 1, 1);
+    share_name.remove(share_name.size() - 1, 1);
   }
 
   return share_name;
