@@ -2,7 +2,7 @@
     Main file of the Smb4K program.
                              -------------------
     begin                : Sam Mär  1 14:57:21 CET 2003
-    copyright            : (C) 2003-2016 by Alexander Reinholdt
+    copyright            : (C) 2003-2020 by Alexander Reinholdt
     email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
@@ -23,8 +23,6 @@
  *   MA 02110-1335, USA                                                    *
  ***************************************************************************/
 
-#include <config.h>
-
 // application specific includes
 #include "smb4kmainwindow.h"
 #include "core/smb4ksettings.h"
@@ -42,6 +40,8 @@
 #include <KDBusAddons/KDBusService>
 #include <KCrash/KCrash>
 
+#include <smb4k_version.h>
+
 using namespace Smb4KGlobal;
 
 
@@ -139,7 +139,8 @@ int main(int argc, char **argv)
   }
   
   // Set attributes
-  QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling, true);
+  QApplication::setAttribute(Qt::AA_EnableHighDpiScaling, true);
+  QApplication::setAttribute(Qt::AA_UseHighDpiPixmaps, true);
   
   // Create the application
   QApplication app(argc, argv);
@@ -148,13 +149,14 @@ int main(int argc, char **argv)
   KLocalizedString::setApplicationDomain("smb4k");
   
   // Create the about data for Smb4K  
-  KAboutData aboutData(QStringLiteral("smb4k"), i18n("Smb4K"), QStringLiteral(VERSION),
+  KAboutData aboutData(QStringLiteral("smb4k"), i18n("Smb4K"), QStringLiteral(SMB4K_VERSION_STRING),
     i18n("Advanced network neighborhood browser and Samba share mounting utility"),
-    KAboutLicense::GPL_V2, i18n("\u00A9 2003-2019 Alexander Reinholdt"), QString(), 
+    KAboutLicense::GPL_V2, i18n("\u00A9 2003-2021 Alexander Reinholdt"), QString(), 
     QStringLiteral("https://smb4k.sourceforge.io"));
   
   // DBus prefix
   aboutData.setOrganizationDomain("kde.org");
+  aboutData.setDesktopFileName(QStringLiteral("org.kde.")+ aboutData.componentName());
   
   // Authors
   aboutData.addAuthor(i18n("Alexander Reinholdt"), i18n("Developer"), QStringLiteral("alexander.reinholdt@kdemail.net"));
@@ -179,9 +181,6 @@ int main(int argc, char **argv)
   // tray is closed.
   app.setQuitOnLastWindowClosed(false);
   
-  // Support high dpi screens
-  app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
-  
   // Program icon
   app.setWindowIcon(QIcon::fromTheme(QLatin1String("smb4k")));
   
