@@ -2,7 +2,7 @@
     The configuration dialog of Smb4K
                              -------------------
     begin                : Sa Apr 14 2007
-    copyright            : (C) 2004-2019 by Alexander Reinholdt
+    copyright            : (C) 2004-2021 by Alexander Reinholdt
     email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
@@ -23,10 +23,6 @@
  *   MA 02110-1335, USA                                                    *
  ***************************************************************************/
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 // application specific includes
 #include "smb4kconfigdialog.h"
 #include "smb4kconfigpageauthentication.h"
@@ -146,7 +142,7 @@ void Smb4KConfigDialog::setupDialog()
   // 
   m_user_interface  = addPage(interface_area, Smb4KSettings::self(), i18n("User Interface"), "preferences-desktop");
   m_network         = addPage(network_area, Smb4KSettings::self(), i18n("Network"), "network-workgroup");
-  m_mounting        = addPage(mount_area, Smb4KMountSettings::self(), i18n("Mounting"), "system-run");
+  m_mounting        = addPage(mount_area, Smb4KMountSettings::self(), i18n("Mounting"), "media-mount");
   m_authentication  = addPage(auth_area, Smb4KSettings::self(), i18n("Authentication"), "dialog-password");
   m_synchronization = addPage(rsync_area, Smb4KSettings::self(),i18n("Synchronization"), "folder-sync");
   m_custom_options  = addPage(custom_area, Smb4KSettings::self(), i18n("Custom Options"), "preferences-system-network");
@@ -180,8 +176,8 @@ void Smb4KConfigDialog::loadCustomOptions()
 {
   if (m_custom_options)
   {
-    QList<OptionsPtr> options = Smb4KCustomOptionsManager::self()->customOptions();
-    m_custom_options->widget()->findChild<Smb4KConfigPageCustomOptions *>()->insertCustomOptions(options);
+    QList<OptionsPtr> optionsList = Smb4KCustomOptionsManager::self()->customOptions(true);
+    m_custom_options->widget()->findChild<Smb4KConfigPageCustomOptions *>()->insertCustomOptions(optionsList);
   }
 }
 
@@ -190,8 +186,32 @@ void Smb4KConfigDialog::saveCustomOptions()
 {
   if (m_custom_options)
   {
-    QList<OptionsPtr> options = m_custom_options->widget()->findChild<Smb4KConfigPageCustomOptions *>()->getCustomOptions();
-    Smb4KCustomOptionsManager::self()->replaceCustomOptions(options);
+    QList<OptionsPtr> optionsList = Smb4KCustomOptionsManager::self()->customOptions(true);
+    QList<OptionsPtr> editedOptionsList = m_custom_options->widget()->findChild<Smb4KConfigPageCustomOptions *>()->getCustomOptions();
+    
+    while (!optionsList.isEmpty())
+    {
+      OptionsPtr options = optionsList.takeFirst();
+      bool foundOptions = false;
+      
+      for (const OptionsPtr &editedOptions : qAsConst(editedOptionsList))
+      {
+        if (editedOptions->url().matches(options->url(), QUrl::RemoveUserInfo|QUrl::RemovePort))
+        {
+          // We do not need to update the custom options, because we are
+          // using QSharedPointers.
+          foundOptions = true;
+          break;
+        }        
+      }
+      
+      if (!foundOptions)
+      {
+        Smb4KCustomOptionsManager::self()->removeCustomOptions(options);
+      }
+    }
+    
+    Smb4KCustomOptionsManager::self()->saveCustomOptions();
   }
 }
 
