@@ -2,7 +2,7 @@
     The configuration page for the mount options
                              -------------------
     begin                : So Mär 22 2015
-    copyright            : (C) 2015-2019 by Alexander Reinholdt
+    copyright            : (C) 2015-2020 by Alexander Reinholdt
     email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
@@ -23,10 +23,6 @@
  *   MA 02110-1335, USA                                                    *
  ***************************************************************************/
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 // application specific includes
 #include "smb4kconfigpagemounting.h"
 #include "core/smb4kglobal.h"
@@ -80,16 +76,12 @@ void Smb4KConfigPageMounting::setupWidget()
   // 
   QWidget *basicTab = new QWidget(this);
   QVBoxLayout *basicTabLayout = new QVBoxLayout(basicTab);
-  basicTabLayout->setSpacing(5);
-  basicTabLayout->setMargin(0);
   
   //
   // Directories
   // 
   QGroupBox *directoryBox = new QGroupBox(i18n("Directories"), basicTab);
-
   QGridLayout *directoryBoxLayout = new QGridLayout(directoryBox);
-  directoryBoxLayout->setSpacing(5);
 
   QLabel *prefixLabel = new QLabel(Smb4KMountSettings::self()->mountPrefixItem()->label(), directoryBox);
   KUrlRequester *prefix = new KUrlRequester(directoryBox);
@@ -101,9 +93,9 @@ void Smb4KConfigPageMounting::setupWidget()
   QCheckBox *lowercaseSubdirs = new QCheckBox(Smb4KMountSettings::self()->forceLowerCaseSubdirsItem()->label(), directoryBox);
   lowercaseSubdirs->setObjectName("kcfg_ForceLowerCaseSubdirs");
 
-  directoryBoxLayout->addWidget(prefixLabel, 0, 0, 0);
-  directoryBoxLayout->addWidget(prefix, 0, 1, 0);
-  directoryBoxLayout->addWidget(lowercaseSubdirs, 1, 0, 1, 2, 0);
+  directoryBoxLayout->addWidget(prefixLabel, 0, 0);
+  directoryBoxLayout->addWidget(prefix, 0, 1);
+  directoryBoxLayout->addWidget(lowercaseSubdirs, 1, 0, 1, 2);
   
   basicTabLayout->addWidget(directoryBox, 0);
   
@@ -112,12 +104,12 @@ void Smb4KConfigPageMounting::setupWidget()
   // 
   QGroupBox *behaviorBox = new QGroupBox(i18n("Behavior"), this);
   QGridLayout *behaviorBoxLayout = new QGridLayout(behaviorBox);
-  behaviorBoxLayout->setSpacing(5);
   
   QCheckBox *remountShares = new QCheckBox(Smb4KMountSettings::self()->remountSharesItem()->label(), behaviorBox);
   remountShares->setObjectName("kcfg_RemountShares");
   
   QLabel *remountAttemptsLabel = new QLabel(Smb4KMountSettings::self()->remountAttemptsItem()->label(), behaviorBox);
+  remountAttemptsLabel->setObjectName("RemountAttemptsLabel");
   remountAttemptsLabel->setIndent(25);
   
   QSpinBox *remountAttempts = new QSpinBox(behaviorBox);
@@ -125,6 +117,7 @@ void Smb4KConfigPageMounting::setupWidget()
   remountAttemptsLabel->setBuddy(remountAttempts);
   
   QLabel *remountIntervalLabel = new QLabel(Smb4KMountSettings::self()->remountIntervalItem()->label(), behaviorBox);
+  remountIntervalLabel->setObjectName("RemountIntervalLabel");  
   remountIntervalLabel->setIndent(25);
   
   QSpinBox *remountInterval = new QSpinBox(behaviorBox);
@@ -144,15 +137,15 @@ void Smb4KConfigPageMounting::setupWidget()
   QCheckBox *detectAllShares = new QCheckBox(Smb4KMountSettings::self()->detectAllSharesItem()->label(), behaviorBox);
   detectAllShares->setObjectName("kcfg_DetectAllShares");
 
-  behaviorBoxLayout->addWidget(remountShares, 0, 0, 1, 2, 0);
-  behaviorBoxLayout->addWidget(remountAttemptsLabel, 1, 0, 0);
-  behaviorBoxLayout->addWidget(remountAttempts, 1, 1, 0);
-  behaviorBoxLayout->addWidget(remountIntervalLabel, 2, 0, 0);
-  behaviorBoxLayout->addWidget(remountInterval, 2, 1, 0);
-  behaviorBoxLayout->addWidget(unmountAllShares, 3, 0, 1, 2, 0);
-  behaviorBoxLayout->addWidget(unmountInaccessibleShares, 4, 0, 1, 2, 0);
-  behaviorBoxLayout->addWidget(unmountForeignShares, 5, 0, 1, 2, 0);
-  behaviorBoxLayout->addWidget(detectAllShares, 6, 0, 1, 2, 0);
+  behaviorBoxLayout->addWidget(remountShares, 0, 0, 1, 2);
+  behaviorBoxLayout->addWidget(remountAttemptsLabel, 1, 0);
+  behaviorBoxLayout->addWidget(remountAttempts, 1, 1);
+  behaviorBoxLayout->addWidget(remountIntervalLabel, 2, 0);
+  behaviorBoxLayout->addWidget(remountInterval, 2, 1);
+  behaviorBoxLayout->addWidget(unmountAllShares, 3, 0, 1, 2);
+  behaviorBoxLayout->addWidget(unmountInaccessibleShares, 4, 0, 1, 2);
+  behaviorBoxLayout->addWidget(unmountForeignShares, 5, 0, 1, 2);
+  behaviorBoxLayout->addWidget(detectAllShares, 6, 0, 1, 2);
   
   basicTabLayout->addWidget(behaviorBox, 0);
   basicTabLayout->addStretch(100);
@@ -164,16 +157,12 @@ void Smb4KConfigPageMounting::setupWidget()
   //
   QWidget *commonTab = new QWidget(this);
   QVBoxLayout *commonTabLayout = new QVBoxLayout(commonTab);
-  commonTabLayout->setSpacing(5);
-  commonTabLayout->setMargin(0);
 
   // 
   // Common options group box
   // 
   QGroupBox *commonOptions = new QGroupBox(i18n("Common Options"), commonTab);
-
   QGridLayout *commonOptionsLayout = new QGridLayout(commonOptions);
-  commonOptionsLayout->setSpacing(5);
 
   // Write access
   QCheckBox *useWriteAccess = new QCheckBox(Smb4KMountSettings::self()->useWriteAccessItem()->label(), commonOptions);
@@ -189,8 +178,8 @@ void Smb4KConfigPageMounting::setupWidget()
     writeAccess->addItem(wa.label);
   }
   
-  commonOptionsLayout->addWidget(useWriteAccess, 0, 0, 0);
-  commonOptionsLayout->addWidget(writeAccess, 0, 1, 0);
+  commonOptionsLayout->addWidget(useWriteAccess, 0, 0);
+  commonOptionsLayout->addWidget(writeAccess, 0, 1);
 
   // Character set
   QCheckBox *useCharacterSet = new QCheckBox(Smb4KMountSettings::self()->useClientCharsetItem()->label(), commonOptions);
@@ -206,8 +195,8 @@ void Smb4KConfigPageMounting::setupWidget()
     characterSet->addItem(c.label);
   }
   
-  commonOptionsLayout->addWidget(useCharacterSet, 1, 0, 0);
-  commonOptionsLayout->addWidget(characterSet, 1, 1, 0);
+  commonOptionsLayout->addWidget(useCharacterSet, 1, 0);
+  commonOptionsLayout->addWidget(characterSet, 1, 1);
 
   // Remote filesystem port
   QCheckBox *useFilesystemPort = new QCheckBox(Smb4KMountSettings::self()->useRemoteFileSystemPortItem()->label(), commonOptions);
@@ -216,8 +205,8 @@ void Smb4KConfigPageMounting::setupWidget()
   QSpinBox *filesystemPort = new QSpinBox(commonOptions);
   filesystemPort->setObjectName("kcfg_RemoteFileSystemPort");
 
-  commonOptionsLayout->addWidget(useFilesystemPort, 2, 0, 0);
-  commonOptionsLayout->addWidget(filesystemPort, 2, 1, 0);
+  commonOptionsLayout->addWidget(useFilesystemPort, 2, 0);
+  commonOptionsLayout->addWidget(filesystemPort, 2, 1);
   
   commonTabLayout->addWidget(commonOptions, 0);
   
@@ -225,15 +214,13 @@ void Smb4KConfigPageMounting::setupWidget()
   // CIFS Unix Extensions Support group box
   // 
   QGroupBox *cifsExtensionSupportBox= new QGroupBox(i18n("CIFS Unix Extensions Support"), commonTab);
-  
   QGridLayout *cifsExtensionSupportLayout = new QGridLayout(cifsExtensionSupportBox);
-  cifsExtensionSupportLayout->setSpacing(5);
   
   // CIFS Unix extensions support
   QCheckBox *cifsExtensionsSupport = new QCheckBox(Smb4KMountSettings::self()->cifsUnixExtensionsSupportItem()->label(), cifsExtensionSupportBox);
   cifsExtensionsSupport->setObjectName("kcfg_CifsUnixExtensionsSupport");
   
-  cifsExtensionSupportLayout->addWidget(cifsExtensionsSupport, 0, 0, 1, 2, 0);
+  cifsExtensionSupportLayout->addWidget(cifsExtensionsSupport, 0, 0, 1, 2);
   
   // User information
   QCheckBox *useUserId = new QCheckBox(Smb4KMountSettings::self()->useUserIdItem()->label(), cifsExtensionSupportBox);
@@ -243,8 +230,7 @@ void Smb4KConfigPageMounting::setupWidget()
   userIdInputWidget->setObjectName("UserIdInputWidget");
 
   QGridLayout *userLayout = new QGridLayout(userIdInputWidget);
-  userLayout->setSpacing(5);
-  userLayout->setMargin(0);
+  userLayout->setContentsMargins(0, 0, 0, 0);
 
   KLineEdit *userId = new KLineEdit(userIdInputWidget);
   userId->setObjectName("kcfg_UserId");
@@ -267,11 +253,11 @@ void Smb4KConfigPageMounting::setupWidget()
     userAction->setData(u.userId().nativeId());
   }
 
-  userLayout->addWidget(userId, 0, 0, 0);
+  userLayout->addWidget(userId, 0, 0);
   userLayout->addWidget(userChooser, 0, 1, Qt::AlignCenter);
   
-  cifsExtensionSupportLayout->addWidget(useUserId, 1, 0, 0);
-  cifsExtensionSupportLayout->addWidget(userIdInputWidget, 1, 1, 0);
+  cifsExtensionSupportLayout->addWidget(useUserId, 1, 0);
+  cifsExtensionSupportLayout->addWidget(userIdInputWidget, 1, 1);
 
   // Group information
   QCheckBox *useGroupId = new QCheckBox(Smb4KMountSettings::self()->useGroupIdItem()->label(), cifsExtensionSupportBox);
@@ -281,8 +267,7 @@ void Smb4KConfigPageMounting::setupWidget()
   groupIdInputWidget->setObjectName("GroupIdInputWidget");
 
   QGridLayout *groupLayout = new QGridLayout(groupIdInputWidget);
-  groupLayout->setSpacing(5);
-  groupLayout->setMargin(0);
+  groupLayout->setContentsMargins(0, 0, 0, 0);
 
   KLineEdit *groupId = new KLineEdit(groupIdInputWidget);
   groupId->setObjectName("kcfg_GroupId");
@@ -305,11 +290,11 @@ void Smb4KConfigPageMounting::setupWidget()
     groupAction->setData(g.groupId().nativeId());
   }
 
-  groupLayout->addWidget(groupId, 0, 0, 0);
+  groupLayout->addWidget(groupId, 0, 0);
   groupLayout->addWidget(groupChooser, 0, 1, Qt::AlignCenter);
   
-  cifsExtensionSupportLayout->addWidget(useGroupId, 2, 0, 0);
-  cifsExtensionSupportLayout->addWidget(groupIdInputWidget, 2, 1, 0);
+  cifsExtensionSupportLayout->addWidget(useGroupId, 2, 0);
+  cifsExtensionSupportLayout->addWidget(groupIdInputWidget, 2, 1);
 
   // File mask
   QCheckBox *useFileMode = new QCheckBox(Smb4KMountSettings::self()->useFileModeItem()->label(), cifsExtensionSupportBox);
@@ -320,8 +305,8 @@ void Smb4KConfigPageMounting::setupWidget()
   fileMode->setClearButtonEnabled(true);
   fileMode->setAlignment(Qt::AlignRight);
   
-  cifsExtensionSupportLayout->addWidget(useFileMode, 3, 0, 0);
-  cifsExtensionSupportLayout->addWidget(fileMode, 3, 1, 0);
+  cifsExtensionSupportLayout->addWidget(useFileMode, 3, 0);
+  cifsExtensionSupportLayout->addWidget(fileMode, 3, 1);
 
   // Directory mask
   QCheckBox *useDirectoryMode = new QCheckBox(Smb4KMountSettings::self()->useDirectoryModeItem()->label(), cifsExtensionSupportBox);
@@ -332,10 +317,10 @@ void Smb4KConfigPageMounting::setupWidget()
   directoryMode->setClearButtonEnabled(true);
   directoryMode->setAlignment(Qt::AlignRight);
 
-  cifsExtensionSupportLayout->addWidget(useDirectoryMode, 4, 0, 0);
-  cifsExtensionSupportLayout->addWidget(directoryMode, 4, 1, 0);
+  cifsExtensionSupportLayout->addWidget(useDirectoryMode, 4, 0);
+  cifsExtensionSupportLayout->addWidget(directoryMode, 4, 1);
 
-  commonTabLayout->addWidget(cifsExtensionSupportBox, 1, 0);
+  commonTabLayout->addWidget(cifsExtensionSupportBox, 1);
   commonTabLayout->addStretch(100);
   
   addTab(commonTab, i18n("Common Mount Settings"));
@@ -345,62 +330,56 @@ void Smb4KConfigPageMounting::setupWidget()
   // 
   QWidget *advancedTab = new QWidget(this);
   QVBoxLayout *advancedTabLayout = new QVBoxLayout(advancedTab);
-  advancedTabLayout->setSpacing(5);
-  advancedTabLayout->setMargin(0);
   
   QGroupBox *advancedOptions = new QGroupBox(i18n("Advanced Options"), advancedTab);
-
   QGridLayout *advancedOptionsLayout = new QGridLayout(advancedOptions);
-  advancedOptionsLayout->setSpacing(5);
   
   // Force Uid
   QCheckBox *forceUid = new QCheckBox(Smb4KMountSettings::self()->forceUIDItem()->label(), advancedOptions);
   forceUid->setObjectName("kcfg_ForceUID");
   
-  advancedOptionsLayout->addWidget(forceUid, 0, 0, 0);
+  advancedOptionsLayout->addWidget(forceUid, 0, 0);
   
   // Force Gid
   QCheckBox *forceGid = new QCheckBox(Smb4KMountSettings::self()->forceGIDItem()->label(), advancedOptions);
   forceGid->setObjectName("kcfg_ForceGID");
   
-  advancedOptionsLayout->addWidget(forceGid, 0, 1, 0);
+  advancedOptionsLayout->addWidget(forceGid, 0, 1);
 
   // Permission checks
   QCheckBox *permissionChecks = new QCheckBox(Smb4KMountSettings::self()->permissionChecksItem()->label(), advancedOptions);
   permissionChecks->setObjectName("kcfg_PermissionChecks");
   
-  advancedOptionsLayout->addWidget(permissionChecks, 1, 0, 0);
+  advancedOptionsLayout->addWidget(permissionChecks, 1, 0);
   
   // Client controls Ids
   QCheckBox *clientControlsIds = new QCheckBox(Smb4KMountSettings::self()->clientControlsIDsItem()->label(), advancedOptions);
   clientControlsIds->setObjectName("kcfg_ClientControlsIDs");
   
-  advancedOptionsLayout->addWidget(clientControlsIds, 1, 1, 0);
+  advancedOptionsLayout->addWidget(clientControlsIds, 1, 1);
 
   // Use server inode numbers
   QCheckBox *useServerInodes = new QCheckBox(Smb4KMountSettings::self()->serverInodeNumbersItem()->label(), advancedOptions);
   useServerInodes->setObjectName("kcfg_ServerInodeNumbers");
   
-  advancedOptionsLayout->addWidget(useServerInodes, 2, 0, 0);
+  advancedOptionsLayout->addWidget(useServerInodes, 2, 0);
 
   // Translate reserved characters
   QCheckBox *translateReservedCharacters = new QCheckBox(Smb4KMountSettings::self()->translateReservedCharsItem()->label(), advancedOptions);
   translateReservedCharacters->setObjectName("kcfg_TranslateReservedChars");
   
-  advancedOptionsLayout->addWidget(translateReservedCharacters, 2, 1, 0);
+  advancedOptionsLayout->addWidget(translateReservedCharacters, 2, 1);
   
   // No locking
   QCheckBox *no_locking = new QCheckBox(Smb4KMountSettings::self()->noLockingItem()->label(), advancedOptions);
   no_locking->setObjectName("kcfg_NoLocking");
   
-  advancedOptionsLayout->addWidget(no_locking, 3, 0, 0);
+  advancedOptionsLayout->addWidget(no_locking, 3, 0);
   
   // Extra widget for the rest of the options
   QWidget *advancedOptionsExtraWidget = new QWidget(advancedOptions);
-
   QGridLayout *advancedOptionsExtraWidgetLayout = new QGridLayout(advancedOptionsExtraWidget);
-  advancedOptionsExtraWidgetLayout->setSpacing(5);
-  advancedOptionsExtraWidgetLayout->setMargin(0);
+  advancedOptionsExtraWidgetLayout->setContentsMargins(0, 0, 0, 0);
   
   // SMB protocol version
   QCheckBox *useSmbProtocol = new QCheckBox(Smb4KMountSettings::self()->useSmbProtocolVersionItem()->label(), advancedOptionsExtraWidget);
@@ -416,8 +395,8 @@ void Smb4KConfigPageMounting::setupWidget()
     smbProtocol->addItem(c.label);
   }
   
-  advancedOptionsExtraWidgetLayout->addWidget(useSmbProtocol, 0, 0, 0);
-  advancedOptionsExtraWidgetLayout->addWidget(smbProtocol, 0, 1, 0);
+  advancedOptionsExtraWidgetLayout->addWidget(useSmbProtocol, 0, 0);
+  advancedOptionsExtraWidgetLayout->addWidget(smbProtocol, 0, 1);
   
   // Cache mode
   QCheckBox *useCacheMode = new QCheckBox(Smb4KMountSettings::self()->useCacheModeItem()->label(), advancedOptionsExtraWidget);
@@ -433,8 +412,8 @@ void Smb4KConfigPageMounting::setupWidget()
     cacheMode->addItem(c.label);
   }
   
-  advancedOptionsExtraWidgetLayout->addWidget(useCacheMode, 1, 0, 0);
-  advancedOptionsExtraWidgetLayout->addWidget(cacheMode, 1, 1, 0);
+  advancedOptionsExtraWidgetLayout->addWidget(useCacheMode, 1, 0);
+  advancedOptionsExtraWidgetLayout->addWidget(cacheMode, 1, 1);
   
   // Security mode
   QCheckBox *useSecurityMode = new QCheckBox(Smb4KMountSettings::self()->useSecurityModeItem()->label(), advancedOptionsExtraWidget);
@@ -450,17 +429,15 @@ void Smb4KConfigPageMounting::setupWidget()
     securityMode->addItem(c.label);
   }
   
-  advancedOptionsExtraWidgetLayout->addWidget(useSecurityMode, 2, 0, 0);
-  advancedOptionsExtraWidgetLayout->addWidget(securityMode, 2, 1, 0);
+  advancedOptionsExtraWidgetLayout->addWidget(useSecurityMode, 2, 0);
+  advancedOptionsExtraWidgetLayout->addWidget(securityMode, 2, 1);
 
   // Additional options
   QLabel *additionalOptionsLabel = new QLabel(Smb4KMountSettings::self()->customCIFSOptionsItem()->label(), advancedOptionsExtraWidget);
   
   QWidget *additionalOptionsWidget = new QWidget(advancedOptionsExtraWidget);
-  
   QHBoxLayout *additionalOptionsWidgetLayout = new QHBoxLayout(additionalOptionsWidget);
-  additionalOptionsWidgetLayout->setSpacing(5);
-  additionalOptionsWidgetLayout->setMargin(0);
+  additionalOptionsWidgetLayout->setContentsMargins(0, 0, 0, 0);
 
   KLineEdit *additionalOptions = new KLineEdit(additionalOptionsWidget);
   additionalOptions->setObjectName("kcfg_CustomCIFSOptions");
@@ -475,10 +452,10 @@ void Smb4KConfigPageMounting::setupWidget()
   additionalOptionsWidgetLayout->addWidget(additionalOptions, 0);
   additionalOptionsWidgetLayout->addWidget(additionalOptionsEdit, 0);
 
-  advancedOptionsExtraWidgetLayout->addWidget(additionalOptionsLabel, 3, 0, 0);
-  advancedOptionsExtraWidgetLayout->addWidget(additionalOptionsWidget, 3, 1, 0);
+  advancedOptionsExtraWidgetLayout->addWidget(additionalOptionsLabel, 3, 0);
+  advancedOptionsExtraWidgetLayout->addWidget(additionalOptionsWidget, 3, 1);
 
-  advancedOptionsLayout->addWidget(advancedOptionsExtraWidget, 4, 0, 1, 2, 0);
+  advancedOptionsLayout->addWidget(advancedOptionsExtraWidget, 4, 0, 1, 2);
   
   advancedTabLayout->addWidget(advancedOptions, 0);
   advancedTabLayout->addStretch(100);
@@ -489,14 +466,16 @@ void Smb4KConfigPageMounting::setupWidget()
   // Adjust widgets
   // 
   slotCIFSUnixExtensionsSupport(Smb4KMountSettings::cifsUnixExtensionsSupport());
+  slotRemountSharesToggled(Smb4KMountSettings::remountShares());
   
   //
   // Connections
   //
   connect(userMenu, SIGNAL(triggered(QAction*)), this, SLOT(slotNewUserTriggered(QAction*)));
   connect(groupMenu, SIGNAL(triggered(QAction*)), this, SLOT(slotNewGroupTriggered(QAction*)));
-  connect(cifsExtensionsSupport, SIGNAL(clicked(bool)), this, SLOT(slotCIFSUnixExtensionsSupport(bool)));
-  connect(additionalOptionsEdit, SIGNAL(clicked(bool)), this, SLOT(slotAdditionalCIFSOptions()));  
+  connect(cifsExtensionsSupport, SIGNAL(toggled(bool)), this, SLOT(slotCIFSUnixExtensionsSupport(bool)));
+  connect(additionalOptionsEdit, SIGNAL(toggled(bool)), this, SLOT(slotAdditionalCIFSOptions()));
+  connect(remountShares, SIGNAL(toggled(bool)), this, SLOT(slotRemountSharesToggled(bool)));
 }
 #elif defined(Q_OS_FREEBSD) || defined(Q_OS_NETBSD)
 //
@@ -509,16 +488,12 @@ void Smb4KConfigPageMounting::setupWidget()
   // 
   QWidget *basicTab = new QWidget(this);
   QVBoxLayout *basicTabLayout = new QVBoxLayout(basicTab);
-  basicTabLayout->setSpacing(5);
-  basicTabLayout->setMargin(0);
-  
+ 
   //
   // Directories
   // 
   QGroupBox *directoryBox = new QGroupBox(i18n("Directories"), basicTab);
-
   QGridLayout *directoryBoxLayout = new QGridLayout(directoryBox);
-  directoryBoxLayout->setSpacing(5);
 
   QLabel *prefixLabel = new QLabel(Smb4KMountSettings::self()->mountPrefixItem()->label(), directoryBox);
   KUrlRequester *prefix = new KUrlRequester(directoryBox);
@@ -530,9 +505,9 @@ void Smb4KConfigPageMounting::setupWidget()
   QCheckBox *lowercaseSubdirs = new QCheckBox(Smb4KMountSettings::self()->forceLowerCaseSubdirsItem()->label(), directoryBox);
   lowercaseSubdirs->setObjectName("kcfg_ForceLowerCaseSubdirs");
 
-  directoryBoxLayout->addWidget(prefixLabel, 0, 0, 0);
-  directoryBoxLayout->addWidget(prefix, 0, 1, 0);
-  directoryBoxLayout->addWidget(lowercaseSubdirs, 1, 0, 1, 2, 0);
+  directoryBoxLayout->addWidget(prefixLabel, 0, 0);
+  directoryBoxLayout->addWidget(prefix, 0, 1);
+  directoryBoxLayout->addWidget(lowercaseSubdirs, 1, 0, 1, 2);
   
   basicTabLayout->addWidget(directoryBox, 0);
   
@@ -541,12 +516,12 @@ void Smb4KConfigPageMounting::setupWidget()
   // 
   QGroupBox *behaviorBox = new QGroupBox(i18n("Behavior"), basicTab);
   QGridLayout *behaviorBoxLayout = new QGridLayout(behaviorBox);
-  behaviorBoxLayout->setSpacing(5);
   
   QCheckBox *remountShares = new QCheckBox(Smb4KMountSettings::self()->remountSharesItem()->label(), behaviorBox);
   remountShares->setObjectName("kcfg_RemountShares");
   
   QLabel *remountAttemptsLabel = new QLabel(Smb4KMountSettings::self()->remountAttemptsItem()->label(), behaviorBox);
+  remountAttemptsLabel->setObjectName("RemountAttemptsLabel");
   remountAttemptsLabel->setIndent(25);
   
   QSpinBox *remountAttempts = new QSpinBox(behaviorBox);
@@ -554,6 +529,7 @@ void Smb4KConfigPageMounting::setupWidget()
   remountAttemptsLabel->setBuddy(remountAttempts);
   
   QLabel *remountIntervalLabel = new QLabel(Smb4KMountSettings::self()->remountIntervalItem()->label(), behaviorBox);
+  remountIntervalLabel->setObjectName("RemountIntervalLabel");  
   remountIntervalLabel->setIndent(25);
   
   QSpinBox *remountInterval = new QSpinBox(behaviorBox);
@@ -570,14 +546,14 @@ void Smb4KConfigPageMounting::setupWidget()
   QCheckBox *detectAllShares = new QCheckBox(Smb4KMountSettings::self()->detectAllSharesItem()->label(), behaviorBox);
   detectAllShares->setObjectName("kcfg_DetectAllShares");
 
-  behaviorBoxLayout->addWidget(remountShares, 0, 0, 1, 2, 0);
-  behaviorBoxLayout->addWidget(remountAttemptsLabel, 1, 0, 0);
-  behaviorBoxLayout->addWidget(remountAttempts, 1, 1, 0);
-  behaviorBoxLayout->addWidget(remountIntervalLabel, 2, 0, 0);
-  behaviorBoxLayout->addWidget(remountInterval, 2, 1, 0);
-  behaviorBoxLayout->addWidget(unmountAllShares, 3, 0, 1, 2, 0);
-  behaviorBoxLayout->addWidget(unmountForeignShares, 4, 0, 1, 2, 0);
-  behaviorBoxLayout->addWidget(detectAllShares, 5, 0, 1, 2, 0);
+  behaviorBoxLayout->addWidget(remountShares, 0, 0, 1, 2);
+  behaviorBoxLayout->addWidget(remountAttemptsLabel, 1, 0);
+  behaviorBoxLayout->addWidget(remountAttempts, 1, 1);
+  behaviorBoxLayout->addWidget(remountIntervalLabel, 2, 0);
+  behaviorBoxLayout->addWidget(remountInterval, 2, 1);
+  behaviorBoxLayout->addWidget(unmountAllShares, 3, 0, 1, 2);
+  behaviorBoxLayout->addWidget(unmountForeignShares, 4, 0, 1, 2);
+  behaviorBoxLayout->addWidget(detectAllShares, 5, 0, 1, 2);
   
   basicTabLayout->addWidget(behaviorBox, 0);
   basicTabLayout->addStretch(100);
@@ -589,15 +565,12 @@ void Smb4KConfigPageMounting::setupWidget()
   // 
   QWidget *mountTab = new QWidget(this);
   QVBoxLayout *mountTabLayout = new QVBoxLayout(mountTab);
-  mountTabLayout->setSpacing(5);
-  mountTabLayout->setMargin(0);
 
   //
   // Common Options
   //
   QGroupBox *commonOptionsBox = new QGroupBox(i18n("Common Options"), mountTab);
   QGridLayout *commonOptionsBoxLayout = new QGridLayout(commonOptionsBox);
-  commonOptionsBoxLayout->setSpacing(5);
 
   // User information
   QCheckBox *useUserId = new QCheckBox(Smb4KMountSettings::self()->useUserIdItem()->label(), commonOptionsBox);
@@ -607,8 +580,7 @@ void Smb4KConfigPageMounting::setupWidget()
   userIdInputWidget->setObjectName("UserIdInputWidget");
 
   QGridLayout *userLayout = new QGridLayout(userIdInputWidget);
-  userLayout->setSpacing(5);
-  userLayout->setMargin(0);
+  userLayout->setContentsMargins(0, 0, 0, 0);
 
   KLineEdit *userId = new KLineEdit(userIdInputWidget);
   userId->setObjectName("kcfg_UserId");
@@ -631,11 +603,11 @@ void Smb4KConfigPageMounting::setupWidget()
     userAction->setData(u.userId().nativeId());
   }
 
-  userLayout->addWidget(userId, 0, 0, 0);
+  userLayout->addWidget(userId, 0, 0);
   userLayout->addWidget(userChooser, 0, 1, Qt::AlignCenter);
   
-  commonOptionsBoxLayout->addWidget(useUserId, 0, 0, 0);
-  commonOptionsBoxLayout->addWidget(userIdInputWidget, 0, 1, 0);
+  commonOptionsBoxLayout->addWidget(useUserId, 0, 0);
+  commonOptionsBoxLayout->addWidget(userIdInputWidget, 0, 1);
   
   // Group information
   QCheckBox *useGroupId = new QCheckBox(Smb4KMountSettings::self()->useGroupIdItem()->label(), commonOptionsBox);
@@ -645,8 +617,7 @@ void Smb4KConfigPageMounting::setupWidget()
   groupIdInputWidget->setObjectName("GroupIdInputWidget");
 
   QGridLayout *groupLayout = new QGridLayout(groupIdInputWidget);
-  groupLayout->setSpacing(5);
-  groupLayout->setMargin(0);
+  groupLayout->setContentsMargins(0, 0, 0, 0);
 
   KLineEdit *groupId = new KLineEdit(groupIdInputWidget);
   groupId->setObjectName("kcfg_GroupId");
@@ -669,11 +640,11 @@ void Smb4KConfigPageMounting::setupWidget()
     groupAction->setData(g.groupId().nativeId());
   }
 
-  groupLayout->addWidget(groupId, 0, 0, 0);
+  groupLayout->addWidget(groupId, 0, 0);
   groupLayout->addWidget(groupChooser, 0, 1, Qt::AlignCenter);
   
-  commonOptionsBoxLayout->addWidget(useGroupId, 1, 0, 0);
-  commonOptionsBoxLayout->addWidget(groupIdInputWidget, 1, 1, 0);
+  commonOptionsBoxLayout->addWidget(useGroupId, 1, 0);
+  commonOptionsBoxLayout->addWidget(groupIdInputWidget, 1, 1);
 
   // File mask
   QCheckBox *useFileMode = new QCheckBox(Smb4KMountSettings::self()->useFileModeItem()->label(), commonOptionsBox);
@@ -684,8 +655,8 @@ void Smb4KConfigPageMounting::setupWidget()
   fileMode->setClearButtonEnabled(true);
   fileMode->setAlignment(Qt::AlignRight);
   
-  commonOptionsBoxLayout->addWidget(useFileMode, 2, 0, 0);
-  commonOptionsBoxLayout->addWidget(fileMode, 2, 1, 0);
+  commonOptionsBoxLayout->addWidget(useFileMode, 2, 0);
+  commonOptionsBoxLayout->addWidget(fileMode, 2, 1);
 
   // Directory mask
   QCheckBox *useDirectoryMode = new QCheckBox(Smb4KMountSettings::self()->useDirectoryModeItem()->label(), commonOptionsBox);
@@ -696,15 +667,14 @@ void Smb4KConfigPageMounting::setupWidget()
   directoryMode->setClearButtonEnabled(true);
   directoryMode->setAlignment(Qt::AlignRight);
 
-  commonOptionsBoxLayout->addWidget(useDirectoryMode, 3, 0, 0);
-  commonOptionsBoxLayout->addWidget(directoryMode, 3, 1, 0);
+  commonOptionsBoxLayout->addWidget(useDirectoryMode, 3, 0);
+  commonOptionsBoxLayout->addWidget(directoryMode, 3, 1);
   
   // 
   // Character sets
   // 
   QGroupBox *characterSetsBox = new QGroupBox(i18n("Character Sets"), mountTab);
   QGridLayout *characterSetsBoxLayout = new QGridLayout(characterSetsBox);
-  characterSetsBoxLayout->setSpacing(5);  
   
   // Client character set
   QCheckBox *useCharacterSets = new QCheckBox(Smb4KMountSettings::self()->useCharacterSetsItem()->label(), characterSetsBox);
@@ -743,11 +713,11 @@ void Smb4KConfigPageMounting::setupWidget()
   
   serverCharacterSetLabel->setBuddy(serverCharacterSet);
   
-  characterSetsBoxLayout->addWidget(useCharacterSets, 0, 0, 1, 2, 0);
-  characterSetsBoxLayout->addWidget(clientCharacterSetLabel, 1, 0, 0);
-  characterSetsBoxLayout->addWidget(clientCharacterSet, 1, 1, 0);
-  characterSetsBoxLayout->addWidget(serverCharacterSetLabel, 2, 0, 0);
-  characterSetsBoxLayout->addWidget(serverCharacterSet, 2, 1, 0);  
+  characterSetsBoxLayout->addWidget(useCharacterSets, 0, 0, 1, 2);
+  characterSetsBoxLayout->addWidget(clientCharacterSetLabel, 1, 0);
+  characterSetsBoxLayout->addWidget(clientCharacterSet, 1, 1);
+  characterSetsBoxLayout->addWidget(serverCharacterSetLabel, 2, 0);
+  characterSetsBoxLayout->addWidget(serverCharacterSet, 2, 1);  
   
   mountTabLayout->addWidget(commonOptionsBox, 0);
   mountTabLayout->addWidget(characterSetsBox, 0);
@@ -761,11 +731,13 @@ void Smb4KConfigPageMounting::setupWidget()
   connect(userMenu, SIGNAL(triggered(QAction*)), this, SLOT(slotNewUserTriggered(QAction*)));
   connect(groupMenu, SIGNAL(triggered(QAction*)), this, SLOT(slotNewGroupTriggered(QAction*)));
   connect(useCharacterSets, SIGNAL(toggled(bool)), this, SLOT(slotCharacterSets(bool)));
+  connect(remountShares, SIGNAL(toggled(bool)), this, SLOT(slotRemountSharesToggled(bool)));
   
   //
   // Enable / disable widgets
   //
   slotCharacterSets(Smb4KMountSettings::useCharacterSets());
+  slotRemountSharesToggled(Smb4KMountSettings::remountShares());
 }
 #else
 //
@@ -881,7 +853,7 @@ void Smb4KConfigPageMounting::slotAdditionalCIFSOptions()
         //
         // This is, among others, the proper fix to the security issue reported
         // by Heiner Markert (aka CVE-2014-2581).
-        QStringList whitelist = whitelistedMountArguments();
+        QStringList allowedArgs = allowedMountArguments();
         QStringList deniedArgs;
         QStringList list = options.split(',', QString::SkipEmptyParts);
         QMutableStringListIterator it(list);
@@ -890,7 +862,7 @@ void Smb4KConfigPageMounting::slotAdditionalCIFSOptions()
         {
           QString arg = it.next().section("=", 0, 0);
           
-          if (!whitelist.contains(arg))
+          if (!allowedArgs.contains(arg))
           {
             deniedArgs << arg;
             it.remove();
@@ -952,3 +924,24 @@ void Smb4KConfigPageMounting::slotCharacterSets(bool on)
   }
 }
 
+
+void Smb4KConfigPageMounting::slotRemountSharesToggled(bool on)
+{
+  //
+  // Get the widget
+  // 
+  QLabel *remountAttemptsLabel = findChild<QLabel *>("RemountAttemptsLabel");
+  QSpinBox *remountAttempts = findChild<QSpinBox *>("kcfg_RemountAttempts");
+  QLabel *remountIntervalLabel = findChild<QLabel *>("RemountIntervalLabel");  
+  QSpinBox *remountInterval = findChild<QSpinBox *>("kcfg_RemountInterval");
+
+  //
+  // Enable / disable the widgets
+  // 
+  remountAttemptsLabel->setEnabled(on);
+  remountAttempts->setEnabled(on);
+  remountIntervalLabel->setEnabled(on);
+  remountInterval->setEnabled(on);
+}
+
+
