@@ -23,10 +23,6 @@
  *   MA 02110-1335, USA                                                    *
  ***************************************************************************/
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 // application specific includes
 #include "smb4kconfigpagesynchronization.h"
 #include "core/smb4ksettings.h"
@@ -54,13 +50,10 @@ Smb4KConfigPageSynchronization::Smb4KConfigPageSynchronization(QWidget *parent)
   // 
   QWidget *basicTab = new QWidget(this);
   QVBoxLayout *basicTabLayout = new QVBoxLayout(basicTab);
-  basicTabLayout->setSpacing(5);
-  basicTabLayout->setMargin(0);
   
   // Default destination (rsync)
   QGroupBox *pathsBox = new QGroupBox(i18n("Default Destination"), basicTab);
   QGridLayout *pathsBoxLayout = new QGridLayout(pathsBox);
-  pathsBoxLayout->setSpacing(5);
 
   QLabel *rsyncPrefixLabel = new QLabel(Smb4KSettings::self()->rsyncPrefixItem()->label(), pathsBox);
   KUrlRequester *rsyncPrefix = new KUrlRequester(pathsBox);
@@ -68,13 +61,12 @@ Smb4KConfigPageSynchronization::Smb4KConfigPageSynchronization(QWidget *parent)
   rsyncPrefix->setObjectName("kcfg_RsyncPrefix");
   rsyncPrefixLabel->setBuddy(rsyncPrefix);
   
-  pathsBoxLayout->addWidget(rsyncPrefixLabel, 0, 0, 0);
-  pathsBoxLayout->addWidget(rsyncPrefix, 0, 1, 0);
+  pathsBoxLayout->addWidget(rsyncPrefixLabel, 0, 0);
+  pathsBoxLayout->addWidget(rsyncPrefix, 0, 1);
   
   // Behavior
   QGroupBox *behaviorBox = new QGroupBox(i18n("Behavior"), basicTab);
   QGridLayout *behaviorBoxLayout = new QGridLayout(behaviorBox);
-  behaviorBoxLayout->setSpacing(5);
   
   QCheckBox *archiveMode = new QCheckBox(Smb4KSettings::self()->archiveModeItem()->label(), behaviorBox);
   archiveMode->setObjectName("kcfg_ArchiveMode");
@@ -87,16 +79,15 @@ Smb4KConfigPageSynchronization::Smb4KConfigPageSynchronization(QWidget *parent)
   QCheckBox *transferDirs = new QCheckBox(Smb4KSettings::self()->transferDirectoriesItem()->label(), behaviorBox);
   transferDirs->setObjectName("kcfg_TransferDirectories");
   
-  behaviorBoxLayout->addWidget(archiveMode, 0, 0, 0);
-  behaviorBoxLayout->addWidget(recurseDirs, 0, 1, 0);
-  behaviorBoxLayout->addWidget(relativePaths, 1, 0, 0);
-  behaviorBoxLayout->addWidget(noImpliedDirs, 1, 1, 0);
-  behaviorBoxLayout->addWidget(transferDirs, 2, 0, 0);
+  behaviorBoxLayout->addWidget(archiveMode, 0, 0);
+  behaviorBoxLayout->addWidget(recurseDirs, 0, 1);
+  behaviorBoxLayout->addWidget(relativePaths, 1, 0);
+  behaviorBoxLayout->addWidget(noImpliedDirs, 1, 1);
+  behaviorBoxLayout->addWidget(transferDirs, 2, 0);
   
   // Backup
   QGroupBox *backupBox = new QGroupBox(i18n("Backup"), basicTab);
   QGridLayout *backupBoxLayout = new QGridLayout(backupBox);
-  backupBoxLayout->setSpacing(5);
 
   QCheckBox *makeBackups = new QCheckBox(Smb4KSettings::self()->makeBackupsItem()->label(), backupBox);
   makeBackups->setObjectName("kcfg_MakeBackups");
@@ -111,11 +102,11 @@ Smb4KConfigPageSynchronization::Smb4KConfigPageSynchronization(QWidget *parent)
   backupDir->setObjectName("kcfg_BackupDirectory");
   backupDir->setMode(KFile::Directory | KFile::LocalOnly);
 
-  backupBoxLayout->addWidget(makeBackups, 0, 0, 0);
-  backupBoxLayout->addWidget(backupSuffixButton, 1, 0, 0);
-  backupBoxLayout->addWidget(backupSuffix, 1, 1, 0);
-  backupBoxLayout->addWidget(backupDirButton, 2, 0, 0);
-  backupBoxLayout->addWidget(backupDir, 2, 1, 0);
+  backupBoxLayout->addWidget(makeBackups, 0, 0);
+  backupBoxLayout->addWidget(backupSuffixButton, 1, 0);
+  backupBoxLayout->addWidget(backupSuffix, 1, 1);
+  backupBoxLayout->addWidget(backupDirButton, 2, 0);
+  backupBoxLayout->addWidget(backupDir, 2, 1);
   
   basicTabLayout->addWidget(pathsBox, 0);
   basicTabLayout->addWidget(behaviorBox, 0);
@@ -129,13 +120,10 @@ Smb4KConfigPageSynchronization::Smb4KConfigPageSynchronization(QWidget *parent)
   // 
   QWidget *fileHandlingTab = new QWidget(this);
   QVBoxLayout *fileHandlingTabLayout = new QVBoxLayout(fileHandlingTab);
-  fileHandlingTabLayout->setSpacing(5);
-  fileHandlingTabLayout->setMargin(0);
   
   // General
   QGroupBox *generalHandlingBox = new QGroupBox(i18n("General"), fileHandlingTab);
   QGridLayout *generalHandlingBoxLayout = new QGridLayout(generalHandlingBox);
-  generalHandlingBoxLayout->setSpacing(5);
   
   QCheckBox *updateTarget = new QCheckBox(Smb4KSettings::self()->updateTargetItem()->label(), generalHandlingBox);
   updateTarget->setObjectName("kcfg_UpdateTarget");
@@ -150,17 +138,16 @@ Smb4KConfigPageSynchronization::Smb4KConfigPageSynchronization(QWidget *parent)
   QCheckBox *ignoreExisting = new QCheckBox(Smb4KSettings::self()->ignoreExistingItem()->label(), generalHandlingBox);
   ignoreExisting->setObjectName("kcfg_IgnoreExisting");
  
-  generalHandlingBoxLayout->addWidget(updateTarget, 0, 0, 0);
-  generalHandlingBoxLayout->addWidget(updateInPlace, 0, 1, 0);
-  generalHandlingBoxLayout->addWidget(sparseFiles, 1, 0, 0);
-  generalHandlingBoxLayout->addWidget(copyFilesWhole, 1, 1, 0);
-  generalHandlingBoxLayout->addWidget(updateExisting, 2, 0, 0);
-  generalHandlingBoxLayout->addWidget(ignoreExisting, 2, 1, 0);
+  generalHandlingBoxLayout->addWidget(updateTarget, 0, 0);
+  generalHandlingBoxLayout->addWidget(updateInPlace, 0, 1);
+  generalHandlingBoxLayout->addWidget(sparseFiles, 1, 0);
+  generalHandlingBoxLayout->addWidget(copyFilesWhole, 1, 1);
+  generalHandlingBoxLayout->addWidget(updateExisting, 2, 0);
+  generalHandlingBoxLayout->addWidget(ignoreExisting, 2, 1);
   
   // Links
   QGroupBox *linksBox = new QGroupBox(i18n("Links"), fileHandlingTab);
   QGridLayout *linksBoxLayout = new QGridLayout(linksBox);
-  linksBoxLayout->setSpacing(5);
   
   QCheckBox *preserveLinks = new QCheckBox(Smb4KSettings::self()->preserveSymlinksItem()->label(), linksBox);
   preserveLinks->setObjectName("kcfg_PreserveSymlinks");
@@ -179,19 +166,18 @@ Smb4KConfigPageSynchronization::Smb4KConfigPageSynchronization(QWidget *parent)
   QCheckBox *keepDirLinks = new QCheckBox(Smb4KSettings::self()->keepDirectorySymlinksItem()->label(), linksBox);
   keepDirLinks->setObjectName("kcfg_KeepDirectorySymlinks");
   
-  linksBoxLayout->addWidget(preserveLinks, 0, 0, 0);
-  linksBoxLayout->addWidget(transformLinks, 0, 1, 0);
-  linksBoxLayout->addWidget(transformUnsafe, 1, 0, 0);
-  linksBoxLayout->addWidget(ignoreUnsafe, 1, 1, 0);
-  linksBoxLayout->addWidget(mungeLinks, 2, 0, 0);
-  linksBoxLayout->addWidget(preserveHlinks, 2, 1, 0);
-  linksBoxLayout->addWidget(copyDirLinks, 3, 0, 0);
-  linksBoxLayout->addWidget(keepDirLinks, 3, 1, 0);
+  linksBoxLayout->addWidget(preserveLinks, 0, 0);
+  linksBoxLayout->addWidget(transformLinks, 0, 1);
+  linksBoxLayout->addWidget(transformUnsafe, 1, 0);
+  linksBoxLayout->addWidget(ignoreUnsafe, 1, 1);
+  linksBoxLayout->addWidget(mungeLinks, 2, 0);
+  linksBoxLayout->addWidget(preserveHlinks, 2, 1);
+  linksBoxLayout->addWidget(copyDirLinks, 3, 0);
+  linksBoxLayout->addWidget(keepDirLinks, 3, 1);
   
   // Permissions & Attributes
   QGroupBox *permissionsBox = new QGroupBox(i18n("Permissions, etc."), fileHandlingTab);
   QGridLayout *permissionsBoxLayout = new QGridLayout(permissionsBox);
-  permissionsBoxLayout->setSpacing(5);
   
   QCheckBox *preservePerms = new QCheckBox(Smb4KSettings::self()->preservePermissionsItem()->label(), permissionsBox);
   preservePerms->setObjectName("kcfg_PreservePermissions");
@@ -206,12 +192,12 @@ Smb4KConfigPageSynchronization::Smb4KConfigPageSynchronization(QWidget *parent)
   QCheckBox *omitDirTimes = new QCheckBox(Smb4KSettings::self()->omitDirectoryTimesItem()->label(), permissionsBox);
   omitDirTimes->setObjectName("kcfg_OmitDirectoryTimes");
   
-  permissionsBoxLayout->addWidget(preservePerms, 0, 0, 0);
-  permissionsBoxLayout->addWidget(preserveOwner, 0, 1, 0);
-  permissionsBoxLayout->addWidget(preserveGroup, 1, 0, 0);
-  permissionsBoxLayout->addWidget(preserveDevices, 1, 1, 0);
-  permissionsBoxLayout->addWidget(preserveTimes, 2, 0, 0);
-  permissionsBoxLayout->addWidget(omitDirTimes, 2, 1, 0);
+  permissionsBoxLayout->addWidget(preservePerms, 0, 0);
+  permissionsBoxLayout->addWidget(preserveOwner, 0, 1);
+  permissionsBoxLayout->addWidget(preserveGroup, 1, 0);
+  permissionsBoxLayout->addWidget(preserveDevices, 1, 1);
+  permissionsBoxLayout->addWidget(preserveTimes, 2, 0);
+  permissionsBoxLayout->addWidget(omitDirTimes, 2, 1);
   
   fileHandlingTabLayout->addWidget(generalHandlingBox, 0);
   fileHandlingTabLayout->addWidget(linksBox, 0);
@@ -225,13 +211,10 @@ Smb4KConfigPageSynchronization::Smb4KConfigPageSynchronization(QWidget *parent)
   // 
   QWidget *transferTab = new QWidget(this);
   QVBoxLayout *transferTabLayout = new QVBoxLayout(transferTab);
-  transferTabLayout->setSpacing(5);
-  transferTabLayout->setMargin(0);
   
   // Compression
   QGroupBox *compressionBox = new QGroupBox(i18n("Compression"), transferTab);
   QGridLayout *compressionBoxLayout = new QGridLayout(compressionBox);
-  compressionBoxLayout->setSpacing(5);
   
   QCheckBox *compressData = new QCheckBox(Smb4KSettings::self()->compressDataItem()->label(), compressionBox);
   compressData->setObjectName("kcfg_CompressData");
@@ -245,16 +228,15 @@ Smb4KConfigPageSynchronization::Smb4KConfigPageSynchronization(QWidget *parent)
   skipCompression->setObjectName("kcfg_SkipCompression");
   skipCompression->setClearButtonEnabled(true);
   
-  compressionBoxLayout->addWidget(compressData, 0, 0, 1, -1, 0);
-  compressionBoxLayout->addWidget(compressionLevelButton, 1, 0, 1, 1, 0);
-  compressionBoxLayout->addWidget(compressionLevel, 1, 1, 1, 1, 0);
-  compressionBoxLayout->addWidget(skipCompressionButton, 2, 0, 1, 1, 0);
-  compressionBoxLayout->addWidget(skipCompression, 2, 1, 1, 1, 0);
+  compressionBoxLayout->addWidget(compressData, 0, 0, 1, -1);
+  compressionBoxLayout->addWidget(compressionLevelButton, 1, 0);
+  compressionBoxLayout->addWidget(compressionLevel, 1, 1);
+  compressionBoxLayout->addWidget(skipCompressionButton, 2, 0);
+  compressionBoxLayout->addWidget(skipCompression, 2, 1);
   
   // Files
   QGroupBox *filesBox = new QGroupBox(i18n("Files"), transferTab);
   QGridLayout *filesBoxLayout = new QGridLayout(filesBox);
-  filesBoxLayout->setSpacing(5);
   
   QCheckBox *minTransferSizeButton = new QCheckBox(Smb4KSettings::self()->useMinimalTransferSizeItem()->label(), filesBox);
   minTransferSizeButton->setObjectName("kcfg_UseMinimalTransferSize");
@@ -274,18 +256,17 @@ Smb4KConfigPageSynchronization::Smb4KConfigPageSynchronization(QWidget *parent)
   partialDir->setObjectName("kcfg_PartialDirectory");
   partialDir->setMode(KFile::Directory | KFile::LocalOnly);
   
-  filesBoxLayout->addWidget(minTransferSizeButton, 0, 0, 0);
-  filesBoxLayout->addWidget(minTransferSize, 0, 1, 0);
-  filesBoxLayout->addWidget(maxTransferSizeButton, 1, 0, 0);
-  filesBoxLayout->addWidget(maxTransferSize, 1, 1, 0);
-  filesBoxLayout->addWidget(keepPartial, 2, 0, 1, -1, 0);
-  filesBoxLayout->addWidget(partialDirButton, 3, 0, 0);
-  filesBoxLayout->addWidget(partialDir, 3, 1, 0);
+  filesBoxLayout->addWidget(minTransferSizeButton, 0, 0);
+  filesBoxLayout->addWidget(minTransferSize, 0, 1);
+  filesBoxLayout->addWidget(maxTransferSizeButton, 1, 0);
+  filesBoxLayout->addWidget(maxTransferSize, 1, 1);
+  filesBoxLayout->addWidget(keepPartial, 2, 0, 1, -1);
+  filesBoxLayout->addWidget(partialDirButton, 3, 0);
+  filesBoxLayout->addWidget(partialDir, 3, 1);
   
   // Miscellaneous
   QGroupBox *miscTransferBox = new QGroupBox(i18n("Miscellaneous"), transferTab);
   QGridLayout *miscTransferBoxLayout = new QGridLayout(miscTransferBox);
-  miscTransferBoxLayout->setSpacing(5);
   
   QCheckBox *bwLimitButton = new QCheckBox(Smb4KSettings::self()->useBandwidthLimitItem()->label(), miscTransferBox);
   bwLimitButton->setObjectName("kcfg_UseBandwidthLimit");
@@ -293,8 +274,8 @@ Smb4KConfigPageSynchronization::Smb4KConfigPageSynchronization(QWidget *parent)
   bwLimit->setObjectName("kcfg_BandwidthLimit");
   bwLimit->setSuffix(i18n(" KiB/s"));
   
-  miscTransferBoxLayout->addWidget(bwLimitButton, 0, 0, 0);
-  miscTransferBoxLayout->addWidget(bwLimit, 0, 1, 0);
+  miscTransferBoxLayout->addWidget(bwLimitButton, 0, 0);
+  miscTransferBoxLayout->addWidget(bwLimit, 0, 1);
   
   transferTabLayout->addWidget(compressionBox, 0);
   transferTabLayout->addWidget(filesBox, 0);
@@ -308,13 +289,10 @@ Smb4KConfigPageSynchronization::Smb4KConfigPageSynchronization(QWidget *parent)
   // 
   QWidget *deleteTab = new QWidget(this);
   QVBoxLayout *deleteTabLayout = new QVBoxLayout(deleteTab);
-  deleteTabLayout->setSpacing(5);
-  deleteTabLayout->setMargin(0);
   
   // Files and Directories
   QGroupBox *filesAndDirsBox = new QGroupBox(i18n("Files && Directories"), deleteTab);
   QGridLayout *filesAndDirsBoxLayout = new QGridLayout(filesAndDirsBox);
-  filesAndDirsBoxLayout->setSpacing(5);
   
   QCheckBox *removeSource = new QCheckBox(Smb4KSettings::self()->removeSourceFilesItem()->label(), filesAndDirsBox);
   removeSource->setObjectName("kcfg_RemoveSourceFiles");
@@ -333,27 +311,26 @@ Smb4KConfigPageSynchronization::Smb4KConfigPageSynchronization(QWidget *parent)
   QCheckBox *forceDirDeletion = new QCheckBox(Smb4KSettings::self()->forceDirectoryDeletionItem()->label(), filesAndDirsBox);
   forceDirDeletion->setObjectName("kcfg_ForceDirectoryDeletion");
   
-  filesAndDirsBoxLayout->addWidget(removeSource, 0, 0, 0);
-  filesAndDirsBoxLayout->addWidget(deleteExtraneous, 0, 1, 0);
-  filesAndDirsBoxLayout->addWidget(deleteBefore, 1, 0, 0);
-  filesAndDirsBoxLayout->addWidget(deleteAfter, 1, 1, 0);
-  filesAndDirsBoxLayout->addWidget(deleteDuring, 2, 0, 0);
-  filesAndDirsBoxLayout->addWidget(deleteExcluded, 2, 1, 0);
-  filesAndDirsBoxLayout->addWidget(ignoreIOErrors, 3, 0, 0);
-  filesAndDirsBoxLayout->addWidget(forceDirDeletion, 3, 1, 0);
+  filesAndDirsBoxLayout->addWidget(removeSource, 0, 0);
+  filesAndDirsBoxLayout->addWidget(deleteExtraneous, 0, 1);
+  filesAndDirsBoxLayout->addWidget(deleteBefore, 1, 0);
+  filesAndDirsBoxLayout->addWidget(deleteAfter, 1, 1);
+  filesAndDirsBoxLayout->addWidget(deleteDuring, 2, 0);
+  filesAndDirsBoxLayout->addWidget(deleteExcluded, 2, 1);
+  filesAndDirsBoxLayout->addWidget(ignoreIOErrors, 3, 0);
+  filesAndDirsBoxLayout->addWidget(forceDirDeletion, 3, 1);
   
   // Restrictions
   QGroupBox *restrictionsBox = new QGroupBox(i18n("Restrictions"), deleteTab);
   QGridLayout *restrictionsBoxLayout = new QGridLayout(restrictionsBox);
-  restrictionsBoxLayout->setSpacing(5);
   
   QCheckBox *maxDeleteButton = new QCheckBox(Smb4KSettings::self()->useMaximumDeleteItem()->label(), restrictionsBox);
   maxDeleteButton->setObjectName("kcfg_UseMaximumDelete");
   QSpinBox *maxDelete = new QSpinBox(restrictionsBox);
   maxDelete->setObjectName("kcfg_MaximumDeleteValue");
   
-  restrictionsBoxLayout->addWidget(maxDeleteButton, 0, 0, 0);
-  restrictionsBoxLayout->addWidget(maxDelete, 0, 1, 0);
+  restrictionsBoxLayout->addWidget(maxDeleteButton, 0, 0);
+  restrictionsBoxLayout->addWidget(maxDelete, 0, 1);
   
   deleteTabLayout->addWidget(filesAndDirsBox, 0);
   deleteTabLayout->addWidget(restrictionsBox, 0);
@@ -366,13 +343,10 @@ Smb4KConfigPageSynchronization::Smb4KConfigPageSynchronization(QWidget *parent)
   //
   QWidget *filterTab = new QWidget(this);
   QVBoxLayout *filterTabLayout = new QVBoxLayout(filterTab);
-  filterTabLayout->setSpacing(5);
-  filterTabLayout->setMargin(0);
 
   // General
   QGroupBox *generalFilterBox = new QGroupBox(i18n("General"), filterTab);
   QGridLayout *generalFilterBoxLayout = new QGridLayout(generalFilterBox);
-  generalFilterBoxLayout->setSpacing(5);
 
   QCheckBox *cvsExclude = new QCheckBox(Smb4KSettings::self()->useCVSExcludeItem()->label(), generalFilterBox);
   cvsExclude->setObjectName("kcfg_UseCVSExclude");
@@ -397,20 +371,19 @@ Smb4KConfigPageSynchronization::Smb4KConfigPageSynchronization(QWidget *parent)
   includeFrom->setObjectName("kcfg_IncludeFrom");
   includeFrom->setMode(KFile::File | KFile::LocalOnly);
 
-  generalFilterBoxLayout->addWidget(cvsExclude, 0, 0, 1, -1, 0);
-  generalFilterBoxLayout->addWidget(excludePatternButton, 1, 0, 0);
-  generalFilterBoxLayout->addWidget(excludePattern, 1, 1, 0);
-  generalFilterBoxLayout->addWidget(excludeFromButton, 2, 0, 0);
-  generalFilterBoxLayout->addWidget(excludeFrom, 2, 1, 0);
-  generalFilterBoxLayout->addWidget(includePatternButton, 3, 0, 0);
-  generalFilterBoxLayout->addWidget(includePattern, 3, 1, 0);
-  generalFilterBoxLayout->addWidget(includeFromButton, 4, 0, 0);
-  generalFilterBoxLayout->addWidget(includeFrom, 4, 1, 0);
+  generalFilterBoxLayout->addWidget(cvsExclude, 0, 0, 1, -1);
+  generalFilterBoxLayout->addWidget(excludePatternButton, 1, 0);
+  generalFilterBoxLayout->addWidget(excludePattern, 1, 1);
+  generalFilterBoxLayout->addWidget(excludeFromButton, 2, 0);
+  generalFilterBoxLayout->addWidget(excludeFrom, 2, 1);
+  generalFilterBoxLayout->addWidget(includePatternButton, 3, 0);
+  generalFilterBoxLayout->addWidget(includePattern, 3, 1);
+  generalFilterBoxLayout->addWidget(includeFromButton, 4, 0);
+  generalFilterBoxLayout->addWidget(includeFrom, 4, 1);
 
   // Filter rules
   QGroupBox *filterRulesBox = new QGroupBox(i18n("Filter Rules"), filterTab);
   QGridLayout *filterRulesBoxLayout = new QGridLayout(filterRulesBox);
-  filterRulesBoxLayout->setSpacing(5);
 
   QLabel *customRulesLabel = new QLabel(Smb4KSettings::self()->customFilteringRulesItem()->label(), filterRulesBox);
   KLineEdit *customRules = new KLineEdit(filterRulesBox);
@@ -423,11 +396,11 @@ Smb4KConfigPageSynchronization::Smb4KConfigPageSynchronization(QWidget *parent)
   QCheckBox *useFFFilterRule = new QCheckBox(Smb4KSettings::self()->useFFFilterRuleItem()->label(), filterRulesBox);
   useFFFilterRule->setObjectName("kcfg_UseFFFilterRule");
   
-  filterRulesBoxLayout->addWidget(customRulesLabel, 0, 0, 0);
-  filterRulesBoxLayout->addWidget(customRules, 0, 1, 0);
-  filterRulesBoxLayout->addWidget(specialRulesLabel, 1, 0, 1, -1, 0);
-  filterRulesBoxLayout->addWidget(useFFilterRule, 2, 0, 1, -1, 0);
-  filterRulesBoxLayout->addWidget(useFFFilterRule, 3, 0, 1, -1, 0);
+  filterRulesBoxLayout->addWidget(customRulesLabel, 0, 0);
+  filterRulesBoxLayout->addWidget(customRules, 0, 1);
+  filterRulesBoxLayout->addWidget(specialRulesLabel, 1, 0, 1, -1);
+  filterRulesBoxLayout->addWidget(useFFilterRule, 2, 0, 1, -1);
+  filterRulesBoxLayout->addWidget(useFFFilterRule, 3, 0, 1, -1);
 
   filterTabLayout->addWidget(generalFilterBox, 0);
   filterTabLayout->addWidget(filterRulesBox, 0);
@@ -440,13 +413,10 @@ Smb4KConfigPageSynchronization::Smb4KConfigPageSynchronization(QWidget *parent)
   //
   QWidget *miscTab = new QWidget(this);
   QVBoxLayout *miscTabLayout = new QVBoxLayout(miscTab);
-  miscTabLayout->setSpacing(5);
-  miscTabLayout->setMargin(0);
 
   // Checksums
   QGroupBox *checksumsBox= new QGroupBox(i18n("Checksums"), miscTab);
   QGridLayout *checksumsBoxLayout = new QGridLayout(checksumsBox);
-  checksumsBoxLayout->setSpacing(5);
 
   QCheckBox *blockSizeButton = new QCheckBox(Smb4KSettings::self()->useBlockSizeItem()->label(), checksumsBox);
   blockSizeButton->setObjectName("kcfg_UseBlockSize");
@@ -460,24 +430,23 @@ Smb4KConfigPageSynchronization::Smb4KConfigPageSynchronization(QWidget *parent)
   QCheckBox *useChecksum = new QCheckBox(Smb4KSettings::self()->useChecksumItem()->label(), checksumsBox);
   useChecksum->setObjectName("kcfg_UseChecksum");
 
-  checksumsBoxLayout->addWidget(blockSizeButton, 0, 0, 0);
-  checksumsBoxLayout->addWidget(blockSize, 0, 1, 0);
-  checksumsBoxLayout->addWidget(checksumSeedButton, 1, 0, 0);
-  checksumsBoxLayout->addWidget(checksumSeed, 1, 1, 0);
-  checksumsBoxLayout->addWidget(useChecksum, 2, 0, 0);
+  checksumsBoxLayout->addWidget(blockSizeButton, 0, 0);
+  checksumsBoxLayout->addWidget(blockSize, 0, 1);
+  checksumsBoxLayout->addWidget(checksumSeedButton, 1, 0);
+  checksumsBoxLayout->addWidget(checksumSeed, 1, 1);
+  checksumsBoxLayout->addWidget(useChecksum, 2, 0);
   
   // Miscellaneous
   QGroupBox *miscBox = new QGroupBox(i18n("Miscellaneous"), miscTab);
   QGridLayout *miscBoxLayout = new QGridLayout(miscBox);
-  miscBoxLayout->setSpacing(5);
 
   QCheckBox *oneFilesystem = new QCheckBox(Smb4KSettings::self()->oneFileSystemItem()->label(), miscBox);
   oneFilesystem->setObjectName("kcfg_OneFileSystem");
   QCheckBox *delayUpdates = new QCheckBox(Smb4KSettings::self()->delayUpdatesItem()->label(), miscBox);
   delayUpdates->setObjectName("kcfg_DelayUpdates");
 
-  miscBoxLayout->addWidget(oneFilesystem, 0, 0, 0);
-  miscBoxLayout->addWidget(delayUpdates, 0, 1, 0);
+  miscBoxLayout->addWidget(oneFilesystem, 0, 0);
+  miscBoxLayout->addWidget(delayUpdates, 0, 1);
 
   miscTabLayout->addWidget(checksumsBox, 0);
   miscTabLayout->addWidget(miscBox, 0);
