@@ -2,7 +2,7 @@
     The main window of Smb4K
                              -------------------
     begin                : Di Jan 1 2008
-    copyright            : (C) 2008-2019 by Alexander Reinholdt
+    copyright            : (C) 2008-2020 by Alexander Reinholdt
     email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
@@ -84,7 +84,7 @@ Smb4KMainWindow::Smb4KMainWindow()
   createStandardStatusBarAction();
   setDockNestingEnabled(true);
   setupActions();
-  setupGUI(QSize(800, 600), Default, "smb4k_shell.rc");
+  setupGUI(Default, "smb4k_shell.rc");
   setupView();
   setupMenuBar();
   setupStatusBar();
@@ -446,8 +446,8 @@ bool Smb4KMainWindow::queryClose()
   {
     // This part has been 'stolen' from JuK application.
     KMessageBox::information(this,
-            i18n("<qt>Closing the main window will keep Smb4K running in the system tray. "
-                  "Use <i>Quit</i> from the <i>File</i> menu to quit the application.</qt>"),
+            i18n("<qt>Closing the main window will keep Smb4K running in the system tray.<br>"
+                 "Use <i>Quit</i> from the <i>File</i> menu to quit the application.</qt>"),
             i18n("Docking"), "DockToSystemTrayInfo");
     setVisible(false);
     return false;
@@ -529,12 +529,7 @@ void Smb4KMainWindow::setupMountIndicator()
   }
   else
   {
-#if KICONTHEMES_VERSION < QT_VERSION_CHECK(5,52,0)
     overlays << "emblem-mounted";
-#else
-    overlays << "";
-    overlays << "emblem-mounted";
-#endif
     m_feedback_icon->setToolTip(i18np("There is currently %1 share mounted.", "There are currently %1 shares mounted.", mountedSharesList().size()));
   }
 
@@ -568,7 +563,7 @@ void Smb4KMainWindow::setupDynamicActionList(QDockWidget* dock)
     // Prepare the dynamic action list for the main window
     //
     QList<QAction *> dynamicList;
-    KActionCollection *dockActionCollection = 0;
+    KActionCollection *dockActionCollection = nullptr;
     
     if (dock->objectName() == "NetworkBrowserDockWidget")
     {
@@ -884,7 +879,7 @@ void Smb4KMainWindow::slotMounterAboutToStart(int process)
 
 void Smb4KMainWindow::slotMounterFinished(int /*process*/)
 {
-  QTimer::singleShot(250, [this] () {
+  QTimer::singleShot(250, this, [this] () {
     if (!coreIsRunning())
     {
       m_progress_bar->setVisible(false);
