@@ -23,13 +23,10 @@
  *   MA 02110-1335, USA                                                    *
  ***************************************************************************/
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 // application specific includes
 #include "smb4ksharesviewdockwidget.h"
 #include "smb4ksharesviewitem.h"
+#include "smb4ktooltip.h"
 #include "core/smb4ksettings.h"
 #include "core/smb4kmounter.h"
 #include "core/smb4ksynchronizer.h"
@@ -475,6 +472,11 @@ void Smb4KSharesViewDockWidget::slotShareMounted(const SharePtr& share)
     // Sort the view
     m_sharesView->sortItems(Qt::AscendingOrder);
     
+    //
+    // Update the tooltip
+    //
+    m_sharesView->toolTip()->update();
+    
     // Enable/disable the 'Unmount All' action
     actionCollection()->action("unmount_all_action")->setEnabled(
       ((!onlyForeignMountedShares() || Smb4KMountSettings::unmountForeignShares()) && m_sharesView->count() != 0));
